NAME = "magic_ball.py"
ORIGINAL_AUTHORS = ["Zakaria Talhami"]

ABOUT = """
Fortune-telling for question using a magic 8 ball
"""

COMMANDS = """
>>> .8ball <<question>>
returns It is certain

>>> .magic8ball <<question>>
returns Very doubtful
"""

WEBSITE = ""



"""
[abbreviation.py]
Abbreviation Plugin

[Author]
Erin Moon, Sourav Dutta

[About]
responds to .def lol

[Commands]
>>> .def lol
returns lots of love
"""


class Plugin:
    abbreviations = {
        "idk": "I don’t know",
        "idc": "I don’t care",
        "idm": "I don’t mind",
        "idr": "I don’t remember",
        "idrm": "I don’t really mind",
        "rly": "really",
        "rlly": "really",
        "sme": "same",
        "sm": "same",
        "lol": "laughing out loud / lots of love",
        "lmao": "laughing my ass off",
        "wtf": "what the fuck",
        "wth": "what the heck",
        "lmfao": "laughing my fucking ass off",
        "kys": "kill your-self",
        "kms": "kill my-self",
        "pls": "please",
        "plz": "please",
        "ye": "yes / yeah",
        "yea": "yes / yeah",
        "so": "significant other / shoutout",
        "bf": "boyfriend",
        "gf": "girlfriend",
        "smh": "shaking my head",
        "cos": "because",
        "cuz": "because",
        "cus": "because",
        "cause": "because",
        "omg": "oh my god",
        "oml": "oh my lord",
        "pic": "picture",
        "wyd": "what you doing",
        "wud": "what you doing",
        "wywd": "what you wanna do",
        "wuwd": "what you wanna do",
        "u": "you",
        "tb": "text back",
        "nr": "no reply(s)",
        "nrs": "no reply(s)",
        "bro": "brother",
        "nm": "nothing much",
        "nvm": "never mind",
        "dm": "direct message / doesn’t matter",
        "tbh": "to be honest",
        "m8": "mate",
        "prob": "pobably",
        "probs": "probably",
        "ly": "love you",
        "lysm": "love you so much",
        "lysfm": "love you so fucking much",
        "lyl": "love you loads",
        "ly2": "love you too",
        "gn": "good-night",
        "gm": "good-morning",
        "jk": "just kidding",
        "jw": "just wondering",
        "ppl": "people",
    }

    def __init__(self):
        pass

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1].split()
            if info["command"] == "PRIVMSG" and msgs[0] == ".def":
                abbreviation = msgs[1].lower()
                if abbreviation in Plugin.abbreviations.keys():
                    methods["send"](info["address"], Plugin.abbreviations[abbreviation])
                else:
                    methods["send"](info["address"], "Result not found!")
        except Exception as e:
            print("woops, abbreviation plugin error", e)



NAME = "googlesearch.py"
ORIGINAL_AUTHORS = ["Justin Walker"]

ABOUT = """
Returns the first three links from a google search.
"""

COMMANDS = """
>>> .google <<search term>>
returns search links
"""

WEBSITE = ""



"""
[quote.py]
Self Trivia Plugin

[Author]
Angel Jimenez

[About]
Returns a private trivia question

[Commands]
>>> .selfTrivia
returns a random question
Currently working on adding multiple choice and a timer reveal.
"""
import random


class Plugin:
    def __init__(self):
        pass

    def trivia(self):
        questions = [
            "Venetian painter Jacopo Robusti was " + "better known by what name?",  # Tintoretto
            "In what town was FDR's " + '"Little White House" located?',  # Warm Springs, Georgia
            "What is the middle color in a rainbow?",  # Green
            "Who was the legendary Benedictine monk " + "who invented champagne?",  # Dom Perignon
            "Great Whites and Hammerheads are what type of animals?",  # Sharks
            "In which year was Alaska sold " + "to the U.S.?",  # In the year 1867
            "Which famous nurse was known as “The Lady Of The Lamp”"
            + " during the crimean war?",  # Florence Nightingale
            "Where did the game of badminton originate?",  # It originated in the British
            # era in the Indian city of Pune (or Poona, as it was known back then)
            "Name the largest freshwater lake in the world?",  # Lake Superior
            "Who invented the telephone?",  # Alexander Graham Bell
            "Who invented the rabies vaccination?",  # Louis Pasteur
            "Name the world’s biggest island.",  # Greenland
            "What is the diameter of Earth?",  # 8,000 miles
            "What’s the coloured part of the human eye called?",  # The iris
            "How many holes are there on a golf course?",  # Eighteen
            "Which word goes before vest, beans and quartet?",  # String
            "Name the world’s largest ocean.",  # Pacific
            "What is the world’s longest river?",  # Amazon
            "By what name are the young of frogs and toads known?",  # Tadpoles
            "What is someone who shoes horses called?",  # A Farrier
            "Where would you find the Sea of Tranquility?",  # The Moon
            "What item of clothing was named after its " + "Scottish inventor?",  # A Mackintosh
            "Who composed the Minute Waltz?",  # Frederic Chopin
            "Who was the first actor to have played the role of James Bond "
            + "in the movie series?",  # Sir Sean Connery
            "Which is the highest mountain in Africa?",  # Mount Kilimanjaro
            "If you boil water you get?",  # Steam
            "How many grams are there in a kilogram?",  # 1,000
            "Where did the Olympic Games originate?",  # Greece
            "How many rings make up the symbol of the Olympic Games?",  # Five
            "Who is the only athlete to win the Olympic marathon twice "
            + "and in successive Olympic games?",  # Abebe Bikila.
            "Who improved the design of the modern-day "
            + "incandescent light bulb?",  # Thomas Edison.
            "By what title were the leaders of ancient Egypt known?",  # Pharoah.
            "Which was the country that first made the use of paper money?",  # China.
            "Which four British cities have underground "
            + "rail systems?",  # Liverpool, Glasgow, Newcastle and London.
            "What % of an egg’s weight is the shell?",  # 12%.
            "Who was the 16th president of the United States?",  # Abraham Lincoln.
            "What kind of weapon is a falchion?",  # A sword.
            "What is the capital city of Spain?",  # Madrid.
            "Which city is the Palace of Versailles nearest to?",  # Paris
            "What is the antonym of the word " + "‘synonym’?",  # Of course, it is ‘antonym’ itself!
            "What is the oldest film ever made, and "
            + "when was it made?",  # Roundhay Garden Scene made in 1888.
            "When was the first atomic bomb " + "dropped?",  # It was dropped on August 6, 1945.
            "Who founded the first public library in the U.S.?",  # Benjamin Franklin.
            "Who is known as the Father of the Modern Olympics?",  # Pierre de Coubertin.
            "Which country is Prague in?",  # Czech Republic.
            "Who was the first gymnast to be awarded a perfect score "
            + "of 10 at the Olympics?",  # Nadia Comaneci.
            "Where would you find the world’s most ancient "
            + "forest?",  # Daintree Forest north of Cairns, Australia.
            "If you suffer from arachnophobia, which animal " + "are you scared of?",  # Spiders.
            "Which famous ocean liner sank on her first voyage in 1912?",  # The Titanic.
            "Name the only heavyweight boxing champion to finish his career of 49 "
            + "fights without ever having been defeated?",  # Rocky Marciano.
            "What is another word for lexicon?",  # Dictionary.
            "Which actress has won the most "
            + "Oscars?",  # Katharine Hepburn, with 4 Oscars and 12 nominations.
            "What is a brontosaurus?",  # A dinosaur.
            "What is the name of the pirate in Peter Pan?",  # Captain Hook.
            "According to legend, who led a gang of merry outlaws in "
            + "Sherwood Forest in Nottingham, England?",  # Robin Hood.
            "What’s the name of the town where The Flintstones live?",  # Bedrock.
            "What is the name of Shrek’s wife?",  # Princess Fiona.
            "Things fall when you drop them because of?",  # gravity
            "Name the seventh planet from the sun.",  # Uranus.
            "Name the three primary colours.",  # Red, yellow and blue.
            "A place to see lots of animals?",  # Zoo.
            "Which English town was a forerunner of the Parks Movement and "
            + "the first city in Europe to have a street tram system?",  # Birkenhead.
            "Which planet is closest to our sun?",  # Mercury.
            "If you freeze water you get?",  # Ice
            "How many legs does a spider have?",  # Eight.
            "He’s “smarter than the average bear”, but what’s the name of "
            + "the most famous resident of Jellystone Park?",  # Yogi Bear.
            "What is the common name for calcium carbonate?",  # Chalk.
            "What holds school supplies and children also "
            + "carry them on their backs?",  # Backpacks.
            "What colour is a stop sign?",  # Red and white.
            "What vehicle runs on a track and blows a whistle?",  # A train.
            "In needlework, what does UFO refer to?",  # An unfinished object.
            "Tired people need?",  # Sleep
            "Is the planet Jupiter larger or smaller than the Earth?",  # Larger.
            "Is a dolphin a mammal?",  # Yes.
            "What do many children ride on to go to school?",  # A school bus.
            "Thirsty people need?",  # Water.
            "What do you wear on your head?",  # Hat.
            "Who painted the Mona Lisa?",  # Leonardo da Vinci.
        ]

        return f"{random.choice(questions)}"

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:]
            if info["command"] == "PRIVMSG" and msgs[0] == ".selfTrivia":
                methods["send"](info["address"], Plugin.trivia(self))
        except Exception as e:
            print("Error with Self Trivia Plugin!", e)



"""
[date.py]
Date Plugin

[Author]
Gico Carlo Evangelista, https://gicocarlo.me/

[About]
Will post the current date

[Commands]
>>> .date today
returns the current date
"""

from datetime import date


class Plugin:
    def __init__(self):
        pass

    # Date attribute
    # Returns date in string format
    def __date():
        curr_date = date.today()
        day = curr_date.strftime("%d")
        month = curr_date.strftime("%B")
        year = curr_date.strftime("%Y")
        return f"Today is {month} {day}, {year}"

    def run(self, incoming, methods, info, bot_info):
        try:
            if info["command"] == "PRIVMSG" and info["args"][1] == ".date today":
                methods["send"](info["address"], Plugin.__date())
        except Exception as e:
            print("woops plug", e)



"""
[basketball.py]
Basketball Plugin

[Author]
Konstantinos Efthymiadis

[About]
Given the event and year as parameters, the plugin will return the countries that won the medal that year
Given the event and country as parameters, the plugin will return the number of medals this country has won

[Commands]
>>> .basketball <<event>> <<year/country>>
returns a string with all the information
>>> .basketball <<event>> <<all>>
returns a table with all the medals of all the years
"""

dataEuroBasket = {
    "1935": ["Latvia", "Spain", "Czechoslovakia", "24-18"],
    "1937": ["Lithuania", "Italy", "France", "24-23"],
    "1939": ["Lithuania", "Latvia", "Poland", "No playOffs"],
    "1946": ["Czechoslovakia", "Italy", "Hungary", "34-32"],
    "1947": ["USSR", "Czechoslovakia", "Egypt", "56-37"],
    "1949": ["Egypt", "France", "Greece", "No playOffs"],
    "1951": ["USSR", "Czechoslovakia", "France", "45-44"],
    "1953": ["USSR", "Hungary", "France", "No playOffs"],
    "1955": ["Hungary", "Czechoslovakia", "USSR", "No playOffs"],
    "1957": ["USSR", "Bulgaria", "Czechoslovakia", "No playOffs"],
    "1959": ["USSR", "Czechoslovakia", "France", "No playOffs"],
    "1961": ["USSR", "Yugoslavia", "Bulgaria", "60-53"],
    "1963": ["USSR", "Poland", "Yugoslavia", "61-45"],
    "1965": ["USSR", "Yugoslavia", "Poland", "58-49"],
    "1967": ["USSR", "Czechoslovakia", "Poland", "89-77"],
    "1969": ["USSR", "Yugoslavia", "Czechoslovakia", "81-72"],
    "1971": ["USSR", "Yugoslavia", "Italy", "69-64"],
    "1973": ["Yugoslavia", "Spain", "USSR", "78-67"],
    "1975": ["Yugoslavia", "USSR", "Italy", "No playOffs"],
    "1977": ["Yugoslavia", "USSR", "Czechoslovakia", "74-61"],
    "1979": ["USSR", "Israel", "Yugoslavia", "98-76"],
    "1981": ["USSR", "Yugoslavia", "Czechoslovakia", "84-67"],
    "1983": ["Italy", "Spain", "USSR", "105-96"],
    "1985": ["USSR", "Czechoslovakia", "Italy", "120-89"],
    "1987": ["Greece", "USSR", "Yugoslavia", "103-101"],
    "1989": ["Yugoslavia", "Greece", "USSR", "98-77"],
    "1991": ["Yugoslavia", "Italy", "Spain", "88-73"],
    "1993": ["Germany", "Russia", "Croatia", "71-70"],
    "1995": ["Yugoslavia", "Lithuania", "Croatia", "96-90"],
    "1997": ["Yugoslavia", "Italy", "Russia", "61-49"],
    "1999": ["Italy", "Spain", "Yugoslavia", "64-56"],
    "2001": ["Yugoslavia", "Turkey", "Spain", "78-69"],
    "2003": ["Lithuania", "Spain", "Italy", "93-84"],
    "2005": ["Greece", "Germany", "France", "78-62"],
    "2007": ["Russia", "Spain", "Lithuania", "60-59"],
    "2009": ["Spain", "Serbia", "Greece", "85-63"],
    "2011": ["Spain", "France", "Russia", "98-85"],
    "2013": ["France", "Lithuania", "Spain", "80-66"],
    "2015": ["Spain", "Lithuania", "France", "80-63"],
    "2017": ["Slovenia", "Serbia", "Spain", "93-85"],
    "2022": ["Spain", "France", "Germany", "88-76"],
}
dataWorldCup = {
    "1950": ["Argentina", "USA", "Chile", "64-50"],
    "1954": ["USA", "Brazil", "Philippines", "62-41"],
    "1959": ["Brazil", "USA", "Chile", "81-67"],
    "1963": ["Brazil", "Yugoslavia", "USSR", "90-71"],
    "1967": ["USSR", "Yugoslavia", "Brazil", "71-59"],
    "1970": ["Yugoslavia", "Brazil", "USSR", "80-55"],
    "1974": ["USSR", "Yugoslavia", "USA", "79-82"],
    "1978": ["Yugoslavia", "USSR", "Brazil", "82-81"],
    "1982": ["USSR", "USA", "Yugoslavia", "95-94"],
    "1986": ["USA", "USSR", "Yugoslavia", "87-85"],
    "1990": ["Yugoslavia", "USSR", "USA", "92-75"],
    "1994": ["USA", "Russia", "Croatia", "137-91"],
    "1998": ["Yugoslavia", "Russia", "USA", "64-62"],
    "2002": ["Yugoslavia", "Argentina", "Germany", "84-77"],
    "2006": ["Spain", "Greece", "USA", "70-47"],
    "2010": ["USA", "Turkey", "Lithuania", "81-64"],
    "2014": ["USA", "Serbia", "France", "129-92"],
    "2019": ["Spain", "Argentina", "France", "95-75"],
}


class Plugin:
    def __init__(self):
        pass

    def __accordingToYear__(year, event):
        dataEvent = {}
        if event == "eu":
            dataEvent = dataEuroBasket
        elif event == "wc":
            dataEvent = dataWorldCup

        if year in dataEvent:
            data = dataEvent.get(year)
            text = "Gold: " + data[0] + "\nSilver: " + data[1] + "\nBronze: " + data[2]
            if data[3] != "No playOffs":
                text += "\nFinal Score:\n" + data[0] + " " + data[3] + " " + data[1]
            return text
        else:
            return "No results for that year"

    def __accordingToCountry__(country, event):
        dataEvent = {}
        if event == "eu":
            dataEvent = dataEuroBasket
        elif event == "wc":
            dataEvent = dataWorldCup

        goldMedal = 0
        silverMedal = 0
        bronzeMedal = 0

        for value in dataEvent.values():
            if value[0].upper() == country.upper():
                goldMedal += 1
            elif value[1].upper() == country.upper():
                silverMedal += 1
            elif value[2].upper() == country.upper():
                bronzeMedal += 1

        if goldMedal == silverMedal and silverMedal == bronzeMedal and bronzeMedal == 0:
            return "The country: " + country + " does not have any medal"
        else:
            text = (
                country
                + " Medals:\n"
                + "Gold: "
                + str(goldMedal)
                + "\nSilver: "
                + str(silverMedal)
                + "\nBronze: "
                + str(bronzeMedal)
                + "\nTotal Medals: "
                + str(goldMedal + silverMedal + bronzeMedal)
            )
            return text

    def __createTable__(maxLen, word):
        whiteCharacters = maxLen - len(word)
        text = ""
        for i in range(0, whiteCharacters // 2):
            text += " "
        text += word
        for i in range(whiteCharacters // 2, whiteCharacters):
            text += " "
        text += "|"
        return text

    def __allTheMedalsAllTheYears__(event):
        dataEvent = {}
        text = ""
        if event == "eu":
            dataEvent = dataEuroBasket
            text = "European Basketball Championship\n"
        elif event == "wc":
            dataEvent = dataWorldCup
            text = "FIBA Basketball World Cup\n"

        if not dataEvent:
            return

        maxForGold = -1
        maxForSilver = -1
        maxForBronze = -1

        for value in dataEvent.values():
            if len(value[0]) > maxForGold:
                maxForGold = len(value[0])
            if len(value[1]) > maxForSilver:
                maxForSilver = len(value[1])
            if len(value[2]) > maxForBronze:
                maxForBronze = len(value[2])

        goldMedal = "Gold Medal"
        silverMedal = "Silver Medal"
        bronzeMedal = "Bronze Medal"

        if len(goldMedal) > maxForGold:
            maxForGold = len(goldMedal)
        if len(silverMedal) > maxForSilver:
            maxForSilver = len(silverMedal)
        if len(bronzeMedal) > maxForBronze:
            maxForBronze = len(bronzeMedal)

        text += "|Year|"
        text += Plugin.__createTable__(maxForGold, goldMedal)
        text += Plugin.__createTable__(maxForSilver, silverMedal)
        text += Plugin.__createTable__(maxForBronze, bronzeMedal)
        text += "\n"

        for key in dataEvent.keys():
            text += "|" + key + "|"
            temp = dataEvent.get(key)

            text += Plugin.__createTable__(maxForGold, temp[0])
            text += Plugin.__createTable__(maxForSilver, temp[1])
            text += Plugin.__createTable__(maxForBronze, temp[2])
            text += "\n"

        return text

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:][0].split()
            if info["command"] == "PRIVMSG" and len(msgs) == 3 and msgs[0] == ".basketball":
                event = msgs[1]
                if msgs[2] == "all":
                    methods["send"](info["address"], Plugin.__allTheMedalsAllTheYears__(msgs[1]))
                elif msgs[2].isnumeric():
                    methods["send"](info["address"], Plugin.__accordingToYear__(msgs[2], msgs[1]))
                else:
                    methods["send"](
                        info["address"], Plugin.__accordingToCountry__(msgs[2], msgs[1])
                    )

        except Exception as e:
            print("Something Wrong. There is a Plugin Error: ", e)



NAME = "Caesar Cipher"
ORIGINAL_AUTHORS = ["Kyle Galloway"]

ABOUT = """
encrypts and decrypts using a caesar cipher
"""

COMMANDS = """
>>> .caesar_cipher <message>
returns the encrypted version of message
"""

WEBSITE = ""



import os
import shutil
from pathlib import Path  # noqa E402

CURRENT_DIR = Path(__file__).parent
MAIN_DIR = CURRENT_DIR.parent
PLUGINS_DIR = os.path.join(MAIN_DIR, "plugins")
SETTINGS_DIR = os.path.join(MAIN_DIR, "settings")
TOML_SETTINGS_FILE = os.path.join(MAIN_DIR, "settings", "settings.toml")


def init(info):
    try:
        shutil.copytree(PLUGINS_DIR, os.path.join(info["cwd"], "plugins"))
        try:
            os.mkdir(os.path.join(info["cwd"], "settings"))
        except:
            pass
        shutil.copy(TOML_SETTINGS_FILE, os.path.join(info["cwd"], "settings", "settings.toml"))
    except FileExistsError:
        pass
    print("created!")



NAME = "channeljoin.py"
ORIGINAL_AUTHORS = ["Marcelo Benesciutti"]

ABOUT = """
Bot Will join a given channel in the server
"""

COMMANDS = """
>>> .channeljoin channel
bot joins the given channel
"""

WEBSITE = ""



NAME = "blackjack.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
Play blackjack
"""

COMMANDS = """
>>>.blackjack create
creates blackjack game

>>>.blackjack join
join blackjack game

>>>.blackjack start
start a round

>>>.blackjack hit
get another card

>>>.blackjack stand
move on to next player
"""



import configparser
import os
import sys

ascii_message = r"""
            _  _                   _         _
  _ __ _  _| || |___ _ _  ___ _  _| |__  ___| |_
 | '_ \ || | __ / _ \ ' \/ -_) || | '_ \/ _ \  _|
 | .__/\_, |_||_\___/_||_\___|\_, |_.__/\___/\__|
 |_|   |__/                   |__/
 github.com/pyhoneybot/honeybot
 ~ IRC bot with awesome plugins
"""


def tab(s=3):
    return " " * s


def line(n=3):
    return "-" * 3


def status(symbol_type):
    if symbol_type in "!i>x":
        return "[" + symbol_type + "]"
    else:
        raise Exception("Undefined symbol type")


def print_honeybot_manifesto(info):
    print(ascii_message)


def print_connect_settings(info):
    settings_path = os.path.join(info["settings_path"], "settings.toml")
    if not os.path.exists(settings_path):
        print("honeybot.api.print :: Could not find settings.toml in", info["settings_path"])
        print("Make sure you are in the right folder")
        sys.exit()
    connect_config = configparser.ConfigParser()
    connect_config.read(settings_path)
    server_url = connect_config["INFO"]["server_url"]
    port = connect_config["INFO"]["port"]
    name = connect_config["INFO"]["name"]

    print(status("i") + " connecting with settings:")
    print(tab() + " server url:", server_url)
    print(tab() + " port:", port)
    print(tab() + " username:", name)
    print(line())



"""
[converter.py]
Currency Converter Plugin

[Author]
Angelo Giacco

[About]
Converts currencies

[Commands]
>>> .convert <<base currency code>> <<target currency code>> <<amount>>
returns the conversion: amount argument is optional with a default of 1
.convert help
shows a list of currencies supported
"""
import math

import requests
from bs4 import BeautifulSoup


class Plugin:
    def __init__(self):
        pass

    currencies = [
        "GBP",
        "EUR",
        "USD",
        "ARS",
        "AUD",
        "BHD",
        "BWP",
        "BRL",
        "BND",
        "BGN",
        "CAD",
        "CLP",
        "CNY",
        "COP",
        "HRK",
        "CZK",
        "DKK",
        "HKD",
        "HUF",
        "ISK",
        "INR",
        "IDR",
        "IRR",
        "ILS",
        "JPY",
        "KZT",
        "KRW",
        "KWD",
        "LYD",
        "MYR",
        "MUR",
        "MXN",
        "NPR",
        "NZD",
        "NOK",
        "OMR",
        "PKR",
        "PHP",
        "PLN",
        "QAR",
        "RON",
        "RUB",
        "SAR",
        "SGD",
        "ZAR",
        "LKR",
        "SEK",
        "CHF",
        "TWD",
        "THB",
        "TTD",
        "TRY",
        "AED",
    ]

    def help(self, methods, info):
        methods["send"](info["address"], "showing supported currencies")
        currency_lists = [
            Plugin.currencies[5 * i : 5 * i + 5]
            for i in range(0, math.ceil(len(Plugin.currencies) / 5))
        ]
        for currency_list in currency_lists:
            methods["send"](info["address"], " ".join(currency_list))

    def conv(self, base_cur, target_cur, amount="1"):
        def is_number(char):
            try:
                float(char)
                return True
            except ValueError:
                return False

        base_cur = base_cur.upper()
        target_cur = target_cur.upper()
        if base_cur not in Plugin.currencies or target_cur not in Plugin.currencies:
            return (
                "one of the currencies is invalid. "
                "enter .converter help to see supported currencies"
            )
        elif not (is_number(amount)):
            return "invalid amount entered, it must be a number. default is 1"
        else:
            base_url = "https://www.x-rates.com/calculator/?"
            url = base_url + "from=" + base_cur + "&to=" + target_cur + "&amount=" + str(amount)
            page = requests.get(url)
            soup = BeautifulSoup(page.text, "html.parser")

            part1 = soup.find(class_="ccOutputTrail").previous_sibling
            part2 = soup.find(class_="ccOutputTrail").get_text(strip=True)
            converted = f"{part1}{part2}"
            return str(amount) + base_cur + " is equal to " + converted + target_cur

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:][0].split()
            if info["command"] == "PRIVMSG" and msgs[0] == ".convert":
                if len(msgs) == 3:
                    methods["send"](info["address"], Plugin.conv(self, msgs[1], msgs[2]))
                elif len(msgs) == 4:
                    methods["send"](info["address"], Plugin.conv(self, msgs[1], msgs[2], msgs[3]))
                elif len(msgs) == 2 and msgs[1] == "help":
                    methods["send"](info["address"], Plugin.help(self, methods, info))
                elif len(msgs) == 2 and msgs[1] != "help":
                    methods["send"](
                        info["address"],
                        "if only two arugments sent, second argument must be help",
                    )
                elif len(msgs) > 4:
                    methods["send"](info["address"], "too many arguments")
                    methods["send"](
                        info["address"], "either two currencies with an optional amount"
                    )
                    methods["send"](info["address"], "or help")
                elif len(msgs) == 1:
                    methods["send"](info["address"], "converter plugin requires arguments:")
                    methods["send"](
                        info["address"], "either two currencies with an optional amount"
                    )
                    methods["send"](info["address"], "or help")
        except Exception as e:
            print("woops converter plugin error ", e)



"""
[roman_numeral.py]
Roman Numeral Converter Plugin

[Author]
Nick Wiley

[About]
Returns the roman numeral equivalent of the number inputted

[Commands]
>>> .roman <number>
returns number represented in roman numerals
"""


class Plugin:
    def __init__(self):
        pass

    def __convert_roman_numeral(self, num):
        """Converts number into a roman numeral"""
        roman_numerals = [
            "I",
            "II",
            "III",
            "IV",
            "V",
            "VI",
            "VII",
            "VIII",
            "IX",
            "X",
            "L",
            "C",
            "D",
            "M",
        ]
        if num >= 1000:
            num -= 1000
            return roman_numerals[13] + Plugin.__convert_roman_numeral(self, num)
        elif num >= 500:
            num -= 500
            return roman_numerals[12] + Plugin.__convert_roman_numeral(self, num)
        elif num >= 400:
            num -= 400
            return (
                roman_numerals[11] + roman_numerals[12] + Plugin.__convert_roman_numeral(self, num)
            )
        elif num >= 100:
            num -= 100
            return roman_numerals[11] + Plugin.__convert_roman_numeral(self, num)
        elif num >= 90:
            num -= 90
            return (
                roman_numerals[9] + roman_numerals[11] + Plugin.__convert_roman_numeral(self, num)
            )
        elif num >= 50:
            num -= 50
            return roman_numerals[10] + Plugin.__convert_roman_numeral(self, num)
        elif num >= 40:
            num -= 40
            return (
                roman_numerals[9] + roman_numerals[10] + Plugin.__convert_roman_numeral(self, num)
            )
        elif num > 10:
            num -= 10
            return roman_numerals[9] + Plugin.__convert_roman_numeral(self, num)
        elif num > 0:
            return roman_numerals[num - 1]
        else:
            return ""

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:][0].split()
            if info["command"] == "PRIVMSG":
                if len(msgs) > 1:
                    if msgs[0] == ".roman":
                        num = int(msgs[1])
                        if num < 1:
                            methods["send"](info["address"], "Input a number greater than 0")
                        else:
                            methods["send"](
                                info["address"],
                                Plugin.__convert_roman_numeral(self, num),
                            )

        except Exception as e:
            print("Error with roman_numeral plugin:", e)



NAME = "dictionary.py"
ORIGINAL_AUTHORS = ["Nishant, JPMorgan Chase & Co."]

ABOUT = """
sends the meaning of the word
requires PyDictionary to be installed
can use pip -> "pip install PyDictionary"
"""

COMMANDS = """
>>> .dictionary <<word>>
returns meaning of the word specified
"""

WEBSITE = ""



"""
[mail.py]
Email plugin

[Author]
Tanner Fry

[About]
Will allow the user to send an email while in the chat
with the bot. The text send will be interpreted as html
so you can use formatting such as <br> to make new lines,
and any other html formatting commands in the text of the
body of the email. No additional libraries need to be installed.
Make sure that you configure the email_config.conf file with your
email, your email password, SMTP server, and SMTP server port.
See that document for more information.

[Commands]
.mail <To email address> .body <Text for the body of your email>
 .subject <Text of subject for email>
EX:// ".mail test@email.com .body testing body for honeybot email
 .subject testing subject"

"""
import configparser
import smtplib
from email.mime.text import MIMEText

# open config file for user credentials to email
email_config = configparser.ConfigParser()
email_config.read("settings/email_config.conf")

# save the read values into their respective variables
USER = email_config["Email"]
PASS = email_config["Password"]
HOST = email_config["SMTP Server"]
PORT = email_config["SMTP Server Port"]

# used to tie into the body of what the user sends, if this is not at the
# front of the message then the message will not appear in the email
text = "\n"


class Plugin:
    def __init__(self):
        pass

    # __email will take 6 parameters to setup the email reconnection
    # and send the message.
    def __email(HOST, PORT, USER, PASS, TO, MSG):
        server = smtplib.SMTP(HOST, int(PORT))
        server.connect(HOST, int(PORT))
        server.starttls()
        server.login(USER, PASS)
        server.sendmail(USER, TO, MSG.as_string())
        server.quit()

    # body is used to loop through the msgs list from the chat
    # and grab everything that was said after .body and before
    # .subject.
    def body(BODY_INDEX, SUBJECT_INDEX, msgs):
        i = BODY_INDEX + 1
        while i < SUBJECT_INDEX:
            if i == BODY_INDEX + 1:
                if msgs[i] == "\n":
                    Body = msgs[i]
                BODY = msgs[i] + " "
            elif i == SUBJECT_INDEX - 1:
                BODY = BODY + msgs[i]
            else:
                if msgs[i] == "\n":
                    Body = BODY + msgs[i]
                BODY = BODY + msgs[i] + " "
            i = i + 1
        return BODY

    # subject is used to loop through the msgs list from the chat
    # and grab everythin after .subject and before the end of the
    # message
    def subject(SUBJECT_INDEX, MAX_INDEX, msgs):
        i = SUBJECT_INDEX + 1
        while i < MAX_INDEX:
            if i == SUBJECT_INDEX + 1:
                SUBJECT = msgs[i] + " "
            elif i == MAX_INDEX - 1:
                SUBJECT = SUBJECT + msgs[i]
            else:
                SUBJECT = SUBJECT + msgs[i] + " "
            i = i + 1
        return SUBJECT

    def run(self, incoming, methods, info, bot_info):
        try:
            # if '!~' in info['prefix']:
            # print(info)
            msgs = info["args"][1:][0].split()
            if info["command"] == "PRIVMSG":
                # makes sure the first parameter is ".mail"
                if msgs[0] == ".mail":
                    TO = msgs[1]  # grabs the TO email provided
                    BODY_INDEX = msgs.index(
                        ".body"
                    )  # gets index for ".body", used in body function
                    SUBJECT_INDEX = msgs.index(
                        ".subject"
                    )  # gets index for ".subject" used in body, and subject functions
                    MAX_INDEX = len(msgs)  # gets max index to know the max indexing value

                    BODY = Plugin.body(
                        BODY_INDEX, SUBJECT_INDEX, msgs
                    )  # fill the BODY string using the body function to extraxt the text
                    SUBJECT = Plugin.subject(
                        SUBJECT_INDEX, MAX_INDEX, msgs
                    )  # fill the SUBJECT string using the
                    # subject function to extract the text

                    MSG = MIMEText(
                        text + BODY, "html"
                    )  # sets MSG format to html, and fills in the BODY portion
                    MSG["Subject"] = SUBJECT  # Fills the MSG's subject with SUBJECT
                    MSG["From"] = USER  # Fills the From field with USER string
                    MSG["To"] = TO  # Fills the TO field with the TO string
                    Plugin.__email(
                        HOST, PORT, USER, PASS, TO, MSG
                    )  # Passes paramters needed to __email to be able to
                    # start up connection to SMTP server and send message

        except Exception as e:
            print("\n*error*\nwoops plugin", __file__, e, "\n")



"""
[proverb.py]
Proverb Plugin

[Author]
Sushant Kumar

[About]
sends a random proverb on request

[Commands]
>>> .proverb
returns a random proverb
"""
import random


class Plugin:
    def __init__(self):
        pass

    def proverb(self):
        proverbs = [
            "Absence makes the heart grow fonder.",
            "Actions speak louder than words.",
            "Don’t put off until tomorrow what you can do today.",
            "Don’t put too many irons in the fire.",
            "Good things come to those who wait.",
            "Half bread is better than nothing.",
            "Where there is smoke there is fire",
            "An early bird catches worm",
            "People who live in glass houses should not throw stones at others",
            "Strike while the iron is hot",
            "Rome was not built in a day",
            "The darkest cloud has the silver lining",
            "As you sow, so you reap",
            "All that glitters is not good",
            "People who live in glass houses should not throw stones at others",
            "A cat has nine lives",
            "Charity begins at home",
            "The dog that bites does not bark",
            "A snake may shed its skin, but it's still a snake",
            "Until the rotten tooth is pulled out, the mouth must chew with caution",
            "Todays flat tits were yesterdays pointed ones",
        ]

        return f"{random.choice(proverbs)}"

    def run(self, incoming, methods, info, bot_info):
        try:
            # if '!~' in info['prefix']:
            # print(info)
            msgs = info["args"][1:]
            if info["command"] == "PRIVMSG" and msgs[0] == ".proverb":
                methods["send"](info["address"], Plugin.proverb(self))
        except Exception as e:
            print("woops plug", e)



"""
[channeljoin.py]
Join Plugin

[Author]
Marcelo Benesciutti

[About]
Bot Will join a given channel in the server

[Commands]
>>> .channeljoin channel
bot joins the given channel
"""


class Plugin:
    def __init__(self):
        pass

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:][0].split()
            if info["command"] == "PRIVMSG" and msgs[0] == ".channeljoin":
                raw_user = info["prefix"]
                user_index = raw_user.find("!")
                user = raw_user[0:user_index]
                with open("settings/OWNERS.conf") as f:
                    for owner in f:
                        if owner.strip() == user:
                            methods["join"](msgs[1])
                            break
                    else:
                        methods["send"](
                            info["address"],
                            "only bot owners can execute this function, "
                            + "make sure your IRC nickname is in the "
                            + "settings/OWNERS.conf file",
                        )

        except Exception as e:
            print("woops plugin error: ", e)



NAME = "russian_roulette.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
In the original russian roulette, you have a one sixth chance of committing
suicide. In this version, you have a one sixth chance of being kicked from
the channel. The bot will utilise the IRC command:
KICK #channel nickname
where #channel is the channel name and nicknames is the nickname of the user
"""

COMMANDS = """
>>> .russian_roulette
either returns a string saying you survived or kicks you off the channel
"""

WEBSITE = ""



""" poker test """

import board
import deck
import game_init
import hand
import player
import pot

# import game_init

deck = deck.Deck()

print(deck.show_deck())
print(deck.nth_card(23))
print(
    deck.nth_card(23).show_card(),
    deck.nth_card(23).figure(),
    deck.nth_card(23).color(),
    deck.nth_card(23).value(),
)
print(deck.draw_by_number(1).show_card())
print(deck.show_deck())
print(deck.draw_by_name("AS").show_card())
print(deck.show_deck())
print(board.Board(deck.make_board()).show_board())
print(hand.Hand(deck.make_hand()).show_hand())
print(len(deck.show_deck()))
print(deck.show_deck())
print(deck.nth_card(66).show_card())

board = board.Board(deck.make_board())

print(board.show_board())
print(deck.show_deck())
print(board.flop())
print(board.flop1())
print(board.flop2())
print(board.flop3())
print(board.turn())
print(board.river())

hand1 = hand.Hand(deck.make_hand())

print(deck.show_deck())
print(hand1.show_hand())
print(hand1.show_hand_obj()[0].show_card())
print(hand1.show_hand_obj()[0].value())
print(hand1.show_hand_obj()[0].color())
print(hand1.best_five(board))
print(hand1.hand_strength(board))

hand2 = hand.Hand(deck.make_hand())

print(deck.show_deck())
print(hand2.show_hand())
print(hand2.show_hand_obj()[1].show_card())
print(hand2.show_hand_obj()[1].value())
print(hand2.show_hand_obj()[1].color())
print(hand2.best_five(board))
print(hand2.hand_strength(board))

player1 = player.Player(1, 100, "yoink")

player1.add_hand(hand1)
print(player1.show_player_hand().show_hand())
print(player1.show_player_hand().show_hand_obj()[0].color())
print(player1.show_player_hand().hand_strength(board))
print(str(player1.chips()))
player1.increase_chips(50)
print(str(player1.chips()))
print(player1.position_name())
player1.add_position(4)
print(player1.position_name())

player2 = player.Player(2, 100, "yeet")

player2.add_hand(hand2)
print(player2.show_player_hand().show_hand())
print(player2.show_player_hand().show_hand_obj()[1].color())
print(player2.show_player_hand().hand_strength(board))
print(str(player2.chips()))
player2.decrease_chips(30)
print(str(player2.chips()))
print(player2.position_name())
player2.add_position(7)
print(player2.position_name())

pot1 = pot.Pot()
print(pot1.show_pot())
pot1.increase_pot(55)
print(pot1.show_pot())
POT = pot.Pot()
print(POT.show_pot())
POT.increase_pot(24)
print(POT.show_pot())
POT.increase_pot(6)
print(POT.show_pot())

print(
    " ".join(
        [c.show_card() for h in game_init.game[3] for c in h.show_player_hand().show_hand_obj()]
    )
)


print(len(game_init.game[0]) + len(game_init.game[1]) + len(game_init.game[3]) * 2)

for play in game_init.game[3]:
    print(
        play.general_name(),
        play.show_player_hand().show_hand(),
        play.chips(),
        play.position_nr(),
        play.position_name(),
        play.show_player_hand().hand_strength(board),
        play.show_player_hand().best_five(board),
    )

game_init.game[0].show_deck()
game_init.game[1].show_board()
for p in game_init.game[3]:
    p.show_player_hand().show_hand()



"""
[log.py]
Log Plugin

[Author]
Gico Carlo Evangelista, https://gicocarlo.me/

[About]
Logs the chat into a log.txt file
"""

# UPDATE: 13/4/2019
# Due to logging module in main.py, log.py will now log the chat using
# standard python file handling

import os
from datetime import datetime

# Makes a new log dir if not existent
# Change according to where you have honeybot dir
log_path = f"{os.getcwd()}/log"
if not os.path.exists(log_path):
    os.makedirs("log")

# Current date
curr_date = datetime.today().strftime("%d-%m-%Y")


class Plugin:
    def __init__(self):
        pass

    def run(self, incoming, methods, info, bot_info):
        msgs = info["args"][1:]
        try:
            if info["command"] == "PRIVMSG":
                # Make log file (if not existent) using current date
                f = open(f"log/{curr_date}.txt", "a+")

                # Current time
                curr_time = datetime.now().strftime("%H:%M:%S")

                # Parse the user ID from info['prefix']
                raw_user = info["prefix"]
                user_index = raw_user.find("!")
                user = raw_user[0:user_index]

                # Logging the chat into txt file
                f.write(f"{curr_time}: {user}: {msgs[0]}\r\n")

        except Exception as e:
            print("woops plugin error ", e)



""" player class """
# pylint: disable=E1601

import game_init


class Player:
    """player class"""

    def __init__(self, nr, chips, username):
        """player initialization"""

        self.__position_nr = nr
        self.__general_name = "player" + str(nr)
        self.__username = username
        self.__chips = chips
        self.__hand = []
        self.add_position(nr)

    def number(self):
        """show number"""

        return self.__number

    def general_name(self):
        """general name"""

        return self.__general_name

    def show_player_hand(self):
        """show hand"""

        return self.__hand

    def add_hand(self, hand):
        """adding hand to player"""

        self.__hand = hand

    def chips(self):
        """show chips"""

        return self.__chips

    def increase_chips(self, win_chips):
        """winning money"""

        self.__chips = self.__chips + win_chips

    def decrease_chips(self, lost_chips):
        """losing money"""

        self.__chips = self.__chips - lost_chips

    def position_nr(self):
        """show position number"""

        return self.__position_nr

    def position_name(self):
        """show position name"""

        return self.__position_name

    def add_position(self, position_nr):
        """adding position"""

        if position_nr >= 0 and position_nr <= 5:
            self.__position_nr = position_nr

            if self.__position_nr == 0:
                self.__position_name = "Small Blind"

            elif self.__position_nr == 1:
                self.__position_name = "Big Blind"

            elif self.__position_nr == 2:
                self.__position_name = "Under the Gun"

            elif self.__position_nr == 3:
                self.__position_name = "Middle"

            elif self.__position_nr == 4:
                self.__position_name = "Tail"

            else:
                self.__position_name = "Dealer"

        else:
            print("Position nr is too big or too little")
            pass

    def bet(self, amount):
        """change game_init to the file where the game info is stored"""
        game_init.game[2].increase_pot(amount)
        self.decrease_chips(0)

    def get_name(self):
        """show player's name"""

        return self.__username

    def add_card_to_hand(self, card):
        """add a card to the player's hand"""
        index = len(self.__hand.show_hand_obj())
        self.__hand.show_hand_obj().append(card)



"""
[duckduckgo.py]
Duckduckgo Plugin

[Author]
Rakesh Seal

[About]
Returns a abstract of the search query from a duckduckgo Search. Return empty if no abstract found.
[Website]


[Commands]
>>> .duck <query>
returns abstrack from duckduckgo search
"""

import requests


class Plugin:
    def __init__(self):
        pass

    def __gen_url_from_query(self, query):
        return "https://duckduckgo.com/?q=" + query + "&format=json&pretty=1"

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:][0].split()
            if info["command"] == "PRIVMSG" and msgs[0] == ".duck":
                query = " ".join(msg for msg in msgs[1:])
                duck_abstract = requests.get(self.__gen_url_from_query(query)).json()["Abstract"]
                methods["send"](info["address"], duck_abstract)
        except Exception as e:
            print("quack quack!", e)



NAME = "url_shorten.py"
ORIGINAL_AUTHORS = ["Rakesh Seal"]

ABOUT = """
Shorten an url with cleanuri and returns the smaller url.
"""

COMMANDS = """
>>> .url_shorten <url>
Shorten an url with cleanuri and returns the smaller url.
"""



NAME = "maths.py"
ORIGINAL_AUTHORS = ["Abdur-Rahmaan Janhangeer, pythonmembers.club"]

ABOUT = """
some maths related commands
"""

COMMANDS = """
>>> .sin <number>
returns sine of number

>>> .cos <number>
returns cosine of number

>>> .tan <number>
returns tangent of number

>>> .rand <number1> <number2>
returns number between number1 and number2
"""

WEBSITE = ""



"""
[diary.py]
Diary Plugin

[Author]
Angelo Giacco

[About]
Keeps a record of your diary

[Commands]
>>>.diary record <diary entry>
Adds to that day's diary entry

>>>.diary show <date>
Will show the diary entry of specified date (can also accept "today", "yesterday")

>>>.diary delete
Will delete today's entry

>>>.diary help
Gives help about how to use the plugin
"""

import os
from datetime import datetime, timedelta

if not os.path.exists("diary"):
    """create diary folder"""

    try:
        os.mkdir("diary")
    except Exception as e:
        print("Something went wrong in diary plugin " + str(e))


class Plugin:
    def __init__(self):
        pass

    def today_yesterday(self, date):
        if date == "today":
            date = datetime.today().strftime("%d-%m-%Y")
        elif date == "yesterday":
            date = datetime.strftime(datetime.now() - timedelta(1), "%d-%m-%Y")
        return date

    def get_path(self, time):
        """get path for diary entry from timestamp"""

        date_obj = datetime.fromtimestamp(time)
        date = date_obj.strftime("%d-%m-%Y")
        path = "diary/" + date
        return path

    def record(self, time, text):
        """adds to existing entry or creates new one"""

        path = Plugin.get_path(self, time)
        if not os.path.exists(path):
            with open(path, "w+") as file:
                content = " ".join(text)
                file.write(content)
                return False
        else:
            with open(path, "a") as file:
                content = " ".join(text)
                file.write(content)
                return True

    def get_record(self, date):
        """
        check if there is a diary entry for a certain date and return it if there is
        """
        date = Plugin.today_yesterday(self, date)
        path = "diary/" + date
        if not os.path.exists(path):
            return [
                "There is no diary entry for that date.",
                "Check the date is entered correctly!",
            ]
        else:
            with open(path) as file:
                entry = file.readlines()
            print([x.strip("\n") for x in entry])
            return [x.strip("\n") for x in entry]

    def delete(self, time):
        """check if entry exists and if it does delete it"""
        path = Plugin.get_path(self, time)
        if not os.path.exists(path):
            return "There is no diary entry for that date. Check the date is entered correctly!"
        else:
            os.remove(path)
            return "Entry deleted successfully!"

    def run(self, incoming, methods, info, bot_info):
        try:
            owner = bot_info["owners"]
            time = bot_info["time"]
            msgs = info["args"][1:][0].split()
            if info["command"] == "PRIVMSG" and msgs[0] == ".diary":
                index = info["prefix"].find("!")
                name = info["prefix"][:index]
                if name not in owner:
                    methods["send"](info["address"], "Access denied! You are not the owner!")
                else:

                    if msgs[1].lower() == "delete":
                        if len(msgs) != 2:
                            methods["send"](info["address"], "Invalid input!")
                        else:
                            methods["send"](info["address"], Plugin.delete(self, time))

                    elif msgs[1].lower() == "show":
                        if len(msgs) != 3:
                            methods["send"](
                                info["address"],
                                "Invalid Input. Try .diary show 21-03-2020",
                            )
                        else:
                            for line in Plugin.get_record(self, msgs[2]):
                                methods["send"](info["address"], line)

                    elif msgs[1].lower() == "record":
                        if len(msgs) > 2:
                            flag = Plugin.record(
                                self, time, msgs[2:]
                            )  # will return true if there was already an entry
                            if flag:
                                methods["send"](
                                    info["address"],
                                    "Text added to diary entry successfully!",
                                )
                            else:
                                methods["send"](
                                    info["address"], "Diary entry created successfully!"
                                )
                        else:
                            methods["send"](info["address"], "No text to record.")

                    elif msgs[1].lower() == "help":
                        methods["send"](info["address"], "Try the following commands!")
                        methods["send"](info["address"], ".diary record this is an example ")
                        methods["send"](
                            info["address"],
                            ".diary show today or .diary show 01-01-2000",
                        )
                        methods["send"](info["address"], ".diary delete")
                        methods["send"](info["address"], "That's all there is to this plugin!")

        except Exception as e:
            print("woops, diary plugin error", e)



import configparser
import unittest

from main import Bot_core as Bot

"""
':appinv!c5e342c5@gateway/web/cgi-irc/kiwiirc.com/ip.200.200.22.200
PRIVMSG ##bottestingmu :ef'
{
'prefix': 'appinv!c5e342c5@gateway/web/cgi-irc/kiwiirc.com/ip.200.200.22.200',
'command': 'PRIVMSG',
'address': '##bottestingmu',
'args': ['##bottestingmu', 'ef']
}
"""
config = configparser.ConfigParser()
config.read("settings/CONNECT.conf")

# incoming
incoming = (
    ":appinv!c5e342c5@gateway/web/cgi-irc/kiwiirc.com/ip.200.200.22.200         PRIVMSG"
    " ##bottestingmu :ef"
)
bot = Bot()


class HoneybotTests(unittest.TestCase):
    """
    basic info
    """

    def test_name(self):
        self.assertEqual(bot.name, config["INFO"]["name"])

    def test_server_url(self):
        self.assertEqual(bot.server_url, config["INFO"]["server_url"])

    def test_port(self):
        self.assertEqual(bot.port, int(config["INFO"]["port"]))

    """
    info function
    """

    def test_info_prefix(self):
        self.assertEqual(
            bot.info(incoming)["prefix"],
            "appinv!c5e342c5@gateway/web/cgi-irc/kiwiirc.com/                    ip.200.200.22.200",
        )

    def test_info_command(self):
        self.assertEqual(bot.info(incoming)["command"], "PRIVMSG")

    def test_info_address(self):
        self.assertEqual(bot.info(incoming)["address"], "##bottestingmu")

    def test_info_args(self):
        self.assertEqual(bot.info(incoming)["args"], ["##bottestingmu", "ef"])

    """
    commands
    """

    def test_set_nick_command(self):
        self.assertEqual(bot.set_nick_command(), "NICK {}\r\n".format(config["INFO"]["name"]))

    def test_present_command(self):
        self.assertEqual(
            bot.present_command(),
            "USER {0} {0} {0} : {0} IRC\r\n".format(config["INFO"]["name"]),
        )

    def test_identify_command(self):
        self.assertEqual(bot.identify_command(), "msg NickServ identify  \r\n")

    def test_join_command(self):
        self.assertEqual(bot.join_channel_command("#abc"), "JOIN #abc \r\n")

    def test_specific_send_command(self):
        self.assertEqual(
            bot.specific_send_command("#abc", "greetings"),
            "PRIVMSG #abc :greetings\r\n",
        )

    def test_pong_return(self):
        self.assertEqual(bot.pong_return("abc"), "PONG :abc\r\n")


if __name__ == "__main__":
    unittest.main()



NAME = "anime.py"

ORIGINAL_AUTHORS = ["Christos Kontos"]

ABOUT = """
This plugin provides detailed information about anime from the top 100 list.
Users can query anime based on rank to get information like name, score, release date, and ranking.
"""

COMMANDS = """
>>> .anime rank <<ranking>> <<info_type>>
Returns the anime information based on rank (1 to 100) and the requested info type (name, score, release_date, ranking).
>>> .anime rank <<ranking>> all
Returns all details (name, score, release date, and ranking) of the anime at the specified rank.
"""



NAME = "Self Travia"
ORIGINAL_AUTHORS = ["Angel Jimenez"]

ABOUT = """
Returns a private trivia question
"""

COMMANDS = """
>>> .selfTrivia
returns a random question
Currently working on adding multiple choice and a timer reveal.
"""

WEBSITE = ""



# Game Objects
class Space:
    def __init__(self, name):
        self.name = name

    def get_name(self):
        return self.name


class Property(Space):
    set_houses = {
        "Violet": 2,
        "Light blue": 3,
        "Purple": 3,
        "Orange": 3,
        "Red": 3,
        "Yellow": 3,
        "Green": 3,
        "Blue": 2,
    }

    def __init__(
        self,
        name,
        color,
        price,
        rent,
        one_house_rent,
        two_house_rent,
        three_house_rent,
        four_house_rent,
        hotel_rent,
        house_cost,
    ):
        super().__init__(name)
        self.price = price
        self.color = color
        self.house_count = 0  # 5 means hotel
        self.rents = {
            0: rent,
            1: one_house_rent,
            2: two_house_rent,
            3: three_house_rent,
            4: four_house_rent,
            5: hotel_rent,
        }
        self.house_cost = house_cost

    def get_house_cost(self):
        return self.house_cost

    def info(self):
        information = [
            self.name + " is a " + self.color + " property that costs " + str(self.price) + ".",
            "It currently has " + str(self.house_count) + " houses.",
            "With no houses rent is " + str(self.rents[0]) + ".",
            "With 1 house rent is " + str(self.rents[1]) + ".",
            "With 2 houses rent is " + str(self.rents[2]) + ".",
            "With 3 houses rent is " + str(self.rents[3]) + ".",
            "With 4 houses rent is " + str(self.rents[4]) + ".",
            "With a hotel rent is " + str(self.rents[5]) + ".",
            "A house costs " + str(self.house_cost) + " to build.",
        ]
        return " ".join(information)


class Railroad(Space):
    def __init__(self, name):
        super().__init__(name)
        self.price = 200
        self.rents = {1: 25, 2: 50, 3: 100, 4: 200}

    def info(self):
        information = [
            self.name + " is a railroad that costs " + str(self.price) + ".",
            "If a player has one railroad only the rent is " + str(self.rents[1]) + ".",
            "If a player has two railroads the rent is " + str(self.rents[2]) + ".",
            "If a player has three railroads only the rent is " + str(self.rents[3]) + ".",
            "If a player has four railroads only the rent is " + str(self.rents[4]) + ".",
        ]
        return " ".join(information)


class Utility(Space):
    def __init__(self, name):
        super().__init__(name)
        self.price = 150
        self.rents = {1: "4 *", 2: "10 *"}

    def info(self):
        return (
            self.name
            + " is a utility that costs "
            + str(self.price)
            + ". If you have "
            + "one utility rent is four times the amount the player rolled on the dice "
            + "or if you have two utilities the rent is ten times!"
        )


board_spaces = [
    Space("GO"),
    Property("Mediterranean Ave.", "Violet", 60, 2, 10, 30, 90, 160, 250, 50),
    Space("Community Card"),
    Property("Baltic Ave.", "Violet", 60, 4, 20, 60, 180, 320, 450, 50),
    Space("Income Tax"),
    Railroad("Reading Railroad"),
    Property("Oriental Ave.", "Light blue", 100, 6, 30, 90, 270, 400, 550, 50),
    Space("Chance Card"),
    Property("Vermont Ave.", "Light blue", 100, 6, 30, 90, 270, 400, 550, 50),
    Property("Conneticut Ave.", "Light blue", 120, 8, 40, 100, 300, 450, 600, 50),
    Space("Jail"),
    Property("St. Charles Pl.", "Purple", 140, 10, 50, 150, 450, 625, 750, 100),
    Utility("Electric Company"),
    Property("States Ave.", "Purple", 140, 10, 50, 150, 450, 625, 750, 100),
    Property("Virginia Ave.", "Purple", 160, 12, 60, 180, 500, 700, 900, 100),
    Railroad("Pennsylvania Railroad"),
    Property("St. James Pl.", "Orange", 180, 14, 70, 200, 550, 750, 950, 100),
    Space("Community Card"),
    Property("Tennessee Ave.", "Orange", 180, 14, 70, 200, 550, 750, 950, 100),
    Property("New York Ave.", "Orange", 200, 16, 80, 220, 600, 800, 1000, 100),
    Space("Free Parking"),
    Property("Kentucky Ave.", "Red", 220, 18, 90, 250, 700, 875, 1050, 150),
    Space("Chance Card"),
    Property("Indiana Ave.", "Red", 220, 18, 90, 250, 700, 875, 1050, 150),
    Property("Illinois Ave.", "Red", 240, 20, 100, 300, 750, 925, 1100, 150),
    Railroad("B. & O. Railroad"),
    Property("Atlantic Ave.", "Yellow", 260, 22, 110, 330, 800, 975, 1150, 150),
    Property("Ventnor Ave.", "Yellow", 260, 22, 110, 330, 800, 975, 1150, 150),
    Utility("Water Works"),
    Property("Marvin Gardens", "Yellow", 280, 24, 120, 360, 850, 1025, 1200, 150),
    Space("Go to Jail"),
    Property("Pacific Ave.", "Green", 300, 26, 130, 390, 900, 1100, 1275, 200),
    Property("No. Carolina Ave.", "Green", 300, 26, 130, 390, 900, 1100, 1275, 200),
    Space("Community Card"),
    Property("Pennsylvania Ave.", "Green", 320, 28, 150, 450, 1000, 1200, 1400, 200),
    Railroad("Short Line Railroad"),
    Space("Chance Card"),
    Property("Park Place", "Blue", 350, 35, 175, 500, 1100, 1300, 1500, 200),
    Space("Luxury Tax"),
    Property("Boardwalk", "Blue", 400, 50, 200, 600, 1400, 1700, 2000, 200),
]

# chance_methods = [pay_all,reading_rail,move_to,go,railroad,get_outta_jail,
# jail,earn,fine,repairs,util,move_back_three]
# in the following decks, the second value of the dictionaries in the array
# must be an iterable and not an int, hence why you will see things like (50,)
# so that python keeps it as a tuple
chance_deck = [
    {"You have been elected chairman of the board, pay each player $50": [0, (50,)]},
    {"Take a ride on the reading, if you pass GO collect $200": [1, ()]},
    {
        "Take a walk on the board walk, advance token to board walk": [
            2,
            (board_spaces[39],),
        ]
    },
    {"Advance to go, collect $200": [3, ()]},
    {
        "Advance token to the nearest Railroad and pay owner Twice the Rental owed. If Railroad is unowned you may buy it from the bank": [
            4,
            (),
        ]
    },
    {
        "Advance token to the nearest Railroad and pay owner Twice the Rental owed. If Railroad is unowned you may buy it from the bank": [
            4,
            (),
        ]
    },
    {"Get out of jail free. This card may be kept until needed or sold": [5, ()]},
    {"Go directly to jail. Do not pass Go, do not collect $200": [6, ()]},
    {"Bank pays you dividend of $50": [7, (50,)]},
    {"Advance to Illinois Ave": [2, (board_spaces[24],)]},
    {"Pay poor tax of $15": [8, (15,)]},
    {
        "Make general repairs on all your property. For each house pay $25, for each hotel $100": [
            9,
            (25, 100),
        ]
    },
    {
        "Advance to St. Charles Place. If you pass Go, collect $200": [
            2,
            (board_spaces[11],),
        ]
    },
    {"Your building and loan matures. Collect $150": [7, (150,)]},
    {
        "Advance token to nearest utility. If Unowned you may buy it from the bank. If owned throw dice and pay owner ten times the amount thrown.": [
            10,
            (),
        ]
    },
    {"Go back 3 spaces": [11, ()]},
]

# cc methods = [earn,get_outta_jail,collect,go,jail,repairs,fine]
community_deck = [
    {"Get out of jail free.": [1, ()]},
    {"From sale of stock, you get $45": [0, (45,)]},
    {
        "Grand opera opening. Collect $50 from every player for opening night seats": [
            2,
            (50,),
        ]
    },
    {"Advance to Go, collect $200": [3, ()]},
    {"Xmas fund matures, collect $100": [0, (100,)]},
    {"Go directly to jail. Do not pass Go. Do not collect $200": [4, ()]},
    {"Life insurance matures, collect $200": [0, (200,)]},
    {
        "You are assessed for street repairs. $40 per house, $115 per hotel": [
            5,
            (40, 115),
        ]
    },
    {"Pay hospital $100": [6, (100,)]},
    {"Income tax refund, collect $20": [0, (20,)]},
    {"Doctor's fee, pay $50": [6, (50,)]},
    {"You inherit $100": [0, (100,)]},
    {"Pay school tax of $150": [6, (150,)]},
    {"Receive for services $25": [0, (25,)]},
    {"Bank error in your favor, collect $200": [0, (200,)]},
    {"You have won second prize in a beauty contest, collect $10": [0, (10,)]},
]



NAME = "sysinfo.py"
ORIGINAL_AUTHORS = ["Girish Mahabir"]

ABOUT = """
Responds to .sysinfo, gets System Information of the host.
"""

COMMANDS = """
>>> .sysinfo
returns General System Information, Boot Date and time, CPU information,
Memory information, Disk Information and Network Information.
"""

WEBSITE = ""



NAME = "basketball.py"

ORIGINAL_AUTHORS = ["Konstantinos Efthymiadis"]

ABOUT = """
Given the event and year as parameters, the plugin will return the countries that won the medal that year
Given the event and country as parameters, the plugin will return the number of medals this country has won
"""

COMMANDS = """
>>> .basketball <<event>> <<year/country>>
returns a string with all the information
>>> .basketball <<event>> <<all>>
returns a table with all the medals of all the years
"""



"""
[news.py]
Greet Plugin

[Author]
Angelo Giacco

[About]
Gets the top 10 headlines around the world from bbc world news

[Commands]
>>> .news
returns string of ten news headlines with newlines between
"""
import requests
from bs4 import BeautifulSoup


class Plugin:
    def __init__(self):
        pass

    def news(self):
        response = requests.get("https://www.bbc.co.uk/news/world")  # gets the world news
        doc = BeautifulSoup(response.text, "html.parser")  # parses website
        headlines = doc.find_all("h3")  # finds headlines
        # now headlines have a newline at the start and the end so
        # we want to get rid of thi hence the wierd indexes for headline.text
        # we also only want the first 10 headlines
        ten_headlines_text_list = [headline.text[:] for headline in headlines[:10]]
        return ten_headlines_text_list  # return the list as a string with newlines

    def run(self, incoming, methods, info, bot_info):
        try:
            if info["command"] == "PRIVMSG" and info["args"][1] == ".news":
                for headline in Plugin.news(self):
                    methods["send"](info["address"], headline)
        except Exception as e:
            print("woops news plugin error ", e)



NAME = "Roman Numeral Converter Plugin"
ORIGINAL_AUTHORS = ["Nick Wiley"]

ABOUT = """
Returns the roman numeral equivalent of the number inputted
"""

COMMANDS = """
>>> .roman <number>
returns number represented in roman numerals
"""

WEBSITE = ""



NAME = "countries.py"
ORIGINAL_AUTHORS = ["Sarvesh Dubey"]

ABOUT = """
Show the dialcode of a given country.
"""

COMMANDS = """
>>> .tel <country_code>
returns the associated country telephone code
"""

WEBSITE = ""



NAME = "duck.py"
ORIGINAL_AUTHORS = ["Rakesh Seal"]

ABOUT = """
Returns a abstract of the search query from a duckduckgo Search. Return empty if no abstract found.
"""

COMMANDS = """
>>> .duck <query>
returns abstrack from duckduckgo search
"""



NAME = "riddle.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
Returns a riddle or whether guess at the answer was correct or not.
"""

COMMANDS = """
>>> .riddle
returns a random riddle

.riddle guess <<attempt>>
returns whether the guess was correct or wrong
"""

WEBSITE = ""



NAME = "pynews.py"
ORIGINAL_AUTHORS = ["Sam Deans"]

ABOUT = """
Finds the top five news items on python.org and prints them to the IRC
"""

COMMANDS = """
>>> .pynews
returns the top 5 python.org news articles
"""

WEBSITE = ""



"""
[pypi.py]
Pypi Search Plugin
[Author]
Donald Lieu
[About]
Searches for Python packages on pypi.org
[Commands]
>>> .pypi <search term>
returns first 3 result links
"""

import requests
from bs4 import BeautifulSoup


class Plugin:
    def __init__(self):
        pass

    def run(self, incoming, methods, info, bot_info):
        try:
            if info["command"] == "PRIVMSG" and info["args"][1][:5] == ".pypi":
                query_: str = info["args"][1][6:]
                payload = {"q": query_}
                url_: str = "https://pypi.org/search/"
                r = requests.get(url_, params=payload)
                soup = BeautifulSoup(r.content, "html.parser")
                # Return a max of 3 results
                num_results = soup.find("strong").get_text()
                # Format string
                if num_results[-1] == "+":
                    num_results = num_results[:-1]
                num_results = int(num_results.replace(",", ""))
                if num_results > 3:
                    num_results = 3
                elif num_results == 0:
                    methods["send"](info["address"], "No results")
                links = soup.find_all("a")
                for i in range(num_results):
                    methods["send"](info["address"], "https://pypi.org" + links[7 + i]["href"])
        except Exception as e:
            print("woops plugin error ", e)



"""
[countries.py]
Country-Capital Plugin

[Author]
Phil Beld

[About]
Show the capital of a given country.

[Commands]
>>> .country <country>
returns the associated capital
"""


class Plugin:
    def __init__(self):
        pass

    def __country(input_country):

        data = [
            "Afghanistan",
            "Kabul",
            "Albania",
            "Tirana",
            "Algeria",
            "Algiers",
            "Andorra",
            "Andorra la Vella",
            "Angola",
            "Luanda",
            "Antigua and Barbuda",
            "Saint John’s",
            "Argentina",
            "Buenos Aires",
            "Armenia",
            "Yerevan",
            "Australia",
            "Canberra",
            "Austria",
            "Vienna",
            "Azerbaijan",
            "Baku",
            "The Bahamas",
            "Nassau",
            "Bahrain",
            "Manama",
            "Bangladesh",
            "Dhaka",
            "Barbados",
            "Bridgetown",
            "Belarus",
            "Minsk",
            "Belgium",
            "Brussels",
            "Belize",
            "Belmopan",
            "Benin",
            "Porto-Novo",
            "Bhutan",
            "Thimphu",
            "Bolivia",
            "La Paz, Sucre",
            "Bosnia and Herzegovina",
            "Sarajevo",
            "Botswana",
            "Gaborone",
            "Brazil",
            "Brasilia",
            "Brunei",
            "Bandar Seri Begawan",
            "Bulgaria",
            "Sofia",
            "Burkina Faso",
            "Ouagadougou",
            "Burundi",
            "Bujumbura",
            "Cambodia",
            "Phnom Penh",
            "Cameroon",
            "Yaounde",
            "Canada",
            "Ottawa",
            "Cape Verde",
            "Praia",
            "Central African Republic",
            "Bangui",
            "Chad",
            "N’Djamena",
            "Chile",
            "Santiago",
            "China",
            "Beijing",
            "Colombia",
            "Bogota",
            "Comoros",
            "Moroni",
            "Congo",
            "Republic of the, Brazzaville",
            "Congo",
            "Democratic Republic of the Kinshasa",
            "Costa Rica",
            "San Jose",
            "Cote d’Ivoire",
            "Yamoussoukro",
            "Croatia",
            "Zagreb",
            "Cuba",
            "Havana",
            "Cyprus",
            "Nicosia",
            "Czech Republic",
            "Prague",
            "Denmark",
            "Copenhagen",
            "Djibouti",
            "Djibouti",
            "Dominica",
            "Roseau",
            "Dominican Republic",
            "Santo Domingo",
            "East Timor",
            "Dili",
            "Ecuador",
            "Quito",
            "Egypt",
            "Cairo",
            "El Salvador",
            "San Salvador",
            "Equatorial Guinea",
            "Malabo",
            "Eritrea",
            "Asmara",
            "Estonia",
            "Tallinn",
            "Ethiopia",
            "Addis Ababa",
            "Fiji",
            "Suva",
            "Finland",
            "Helsinki",
            "France",
            "Paris",
            "Gabon",
            "Libreville",
            "The Gambia",
            "Banjul",
            "Georgia",
            "Tbilisi",
            "Germany",
            "Berlin",
            "Ghana",
            "Accra",
            "Greece",
            "Athens",
            "Grenada",
            "Saint George’s",
            "Guatemala",
            "Guatemala City",
            "Guinea",
            "Conakry",
            "Guinea-Bissau",
            "Bissau",
            "Guyana",
            "Georgetown",
            "Haiti",
            "Port-au-Prince",
            "Honduras",
            "Tegucigalpa",
            "Hungary",
            "Budapest",
            "Iceland",
            "Reykjavik",
            "India",
            "New Delhi",
            "Indonesia",
            "Jakarta",
            "Iran",
            "Tehran",
            "Iraq",
            "Baghdad",
            "Ireland",
            "Dublin",
            "Israel",
            "Telaviv",
            "Italy",
            "Rome",
            "Jamaica",
            "Kingston",
            "Japan",
            "Tokyo",
            "Jordan",
            "Amman",
            "Kazakhstan",
            "Astana",
            "Kenya",
            "Nairobi",
            "Kiribati",
            "Tarawa Atoll",
            "Korea",
            "North, Pyongyang",
            "Korea",
            "South, Seoul",
            "Kosovo",
            "Pristina",
            "Kuwait",
            "Kuwait City",
            "Kyrgyzstan",
            "Bishkek",
            "Laos",
            "Vientiane",
            "Latvia",
            "Riga",
            "Lebanon",
            "Beirut",
            "Lesotho",
            "Maseru",
            "Liberia",
            "Monrovia",
            "Libya",
            "Tripoli",
            "Liechtenstein",
            "Vaduz",
            "Lithuania",
            "Vilnius",
            "Luxembourg",
            "Luxembourg",
            "Macedonia",
            "Skopje",
            "Madagascar",
            "Antananarivo",
            "Malawi",
            "Lilongwe",
            "Malaysia",
            "Kuala Lumpur",
            "Maldives",
            "Male",
            "Mali",
            "Bamako",
            "Malta",
            "Valletta",
            "Marshall Islands",
            "Majuro",
            "Mauritania",
            "Nouakchott",
            "Mauritius",
            "Port Louis",
            "Mexico",
            "Mexico City",
            "Micronesia",
            "Federated States of, Palikir",
            "Moldova",
            "Chisinau",
            "Monaco",
            "Monaco",
            "Mongolia",
            "Ulaanbaatar",
            "Montenegro",
            "Podgorica",
            "Morocco",
            "Rabat",
            "Mozambique",
            "Maputo",
            "Myanmar",
            "Naypyidaw",
            "Namibia",
            "Windhoek",
            "Nauru",
            "Yaren District",
            "Nepal",
            "Kathmandu",
            "Netherlands",
            "Amsterdam",
            "New Zealand",
            "Wellington",
            "Nicaragua",
            "Managua",
            "Niger",
            "Niamey",
            "Nigeria",
            "Abuja",
            "Norway",
            "Oslo",
            "Oman",
            "Muscat",
            "Pakistan",
            "Islamabad",
            "Palau",
            "Melekeok",
            "Panama",
            "Panama City",
            "Papua New Guinea",
            "Port Moresby",
            "Paraguay",
            "Asuncion",
            "Peru",
            "Lima",
            "Philippines",
            "Manila",
            "Poland",
            "Warsaw",
            "Portugal",
            "Lisbon",
            "Qatar",
            "Doha",
            "Romania",
            "Bucharest",
            "Russia",
            "Moscow",
            "Rwanda",
            "Kigali",
            "Saint Kitts and Nevis",
            "Basseterre",
            "Saint Lucia",
            "Castries",
            "Saint Vincent and the Grenadines",
            "Kingstown",
            "Samoa",
            "Apia",
            "San Marino",
            "San Marino",
            "Sao Tome and Principe",
            "Sao Tome",
            "Saudi Arabia",
            "Riyadh",
            "Senegal",
            "Dakar",
            "Serbia",
            "Belgrade",
            "Seychelles",
            "Victoria",
            "Sierra Leone",
            "Freetown",
            "Singapore",
            "Singapore",
            "Slovakia",
            "Bratislava",
            "Slovenia",
            "Ljubljana",
            "Solomon Islands",
            "Honiara",
            "Somalia",
            "Mogadishu",
            "South Africa",
            "Pretoria",
            "South Sudan",
            "Juba",
            "Spain",
            "Madrid",
            "Sri Lanka, Colombo",
            "Sri Jayewardenepura Kotte",
            "Sudan",
            "Khartoum",
            "Suriname",
            "Paramaribo",
            "Swaziland",
            "Mbabane",
            "Sweden",
            "Stockholm",
            "Switzerland",
            "Bern",
            "Syria",
            "Damascus",
            "Taiwan",
            "Taipei",
            "Tajikistan",
            "Dushanbe",
            "Tanzania",
            "Dodoma",
            "Thailand",
            "Bangkok",
            "Togo",
            "Lome",
            "Tonga",
            "Nuku’alofa",
            "Trinidad and Tobago",
            "Port-of-Spain",
            "Tunisia",
            "Tunis",
            "Turkey",
            "Ankara",
            "Turkmenistan",
            "Ashgabat",
            "Tuvalu",
            "Funafuti",
            "Uganda",
            "Kampala",
            "Ukraine",
            "Kyiv",
            "United Arab Emirates",
            "Abu Dhabi",
            "United Kingdom",
            "London",
            "United States of America",
            "Washington D.C.",
            "Uruguay",
            "Montevideo",
            "Uzbekistan",
            "Tashkent",
            "Vanuatu",
            "Port-Vila",
            "Vatican City",
            "Vatican City",
            "Venezuela",
            "Caracas",
            "Vietnam",
            "Hanoi",
            "Yemen",
            "Sanaa",
            "Zambia",
            "Lusaka",
            "Zimbabwe",
            "Harare",
        ]

        city = None
        for ii in range(len(data)):
            if str(input_country) == data[ii]:
                city = data[ii + 1]
            else:
                pass
        return city

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"]
            input_country = str(msgs[1][9:])

            if info["command"] == "PRIVMSG" and info["args"][1][1:8] == "country":
                methods["send"](info["address"], Plugin.__country(input_country))
        except Exception as e:
            print("woops plugin error: ", e)



NAME = "installed_module.py"
ORIGINAL_AUTHORS = ["Abdur-Rahmaan Janhangeer, pythonmembers.club"]

ABOUT = """
checks if all listed in requirements.txt installed
"""

COMMANDS = """
>>> .installed
"""

WEBSITE = ""



#!/usr/bin/env python3
import argparse
import logging
import os
import sys

try:
    from honeybot.api.generate import gen_pluginsinfo
    from honeybot.api.init import init
    from honeybot.api.main import BotCore
    from honeybot.api.print import print_connect_settings, print_honeybot_manifesto
except Exception as e:
    print(e)


logging.basicConfig(
    level=logging.DEBUG,
    format="%(asctime)s %(name)s %(levelname)s - %(message)s",
    datefmt="%Y-%m-%d %H:%M:%S",
)


def main():
    parser = argparse.ArgumentParser()

    parser.add_argument("botsetting", choices=["run", "gen_pluginsinfo", "init"])

    args = parser.parse_args()

    info = {
        "cwd": os.getcwd(),
        "settings_path": os.path.join(os.getcwd(), "settings"),
        "toml_path": os.path.join(os.getcwd(), "settings", "settings.toml"),
        "plugins_path": os.path.join(os.getcwd(), "plugins"),
    }

    print_honeybot_manifesto(info)
    if args.botsetting == "run":

        print_connect_settings(info)
        try:
            x = BotCore(info)
            x.unregistered_run()
        except KeyboardInterrupt:
            print("interrupted")
            sys.exit()

    elif args.botsetting == "gen_pluginsinfo":
        gen_pluginsinfo()

    elif args.botsetting == "init":
        init(info)


if __name__ == "__main__":
    main()



"""
[onthisday.py]
On This Day
[Author]
Kenneth Gargan
[About]
Gets an interesting fact about today!
[Commands]
>>> .onthisday
returns fact's about today
"""

import datetime
import json
import random

import requests

# URL where we are getting the facts from:
URL = "https://byabbe.se/on-this-day/"


class Plugin:
    def __init__(self):
        pass

    def run(self, incoming, methods, info, bot_info):
        try:
            if info["command"] == "PRIVMSG" and info["args"][1] == ".onthisday":
                # Make the request and include the month and day
                dt = datetime.datetime.today()
                r = requests.get(
                    "https://byabbe.se/on-this-day/"
                    + str(dt.month)
                    + "/"
                    + str(dt.day)
                    + "/events.json"
                )

                events = json.loads(r.content)
                # Pick out a random fact to print
                randomChoice = random.choice(events["events"])
                onthisday = (
                    "On this day in"
                    + randomChoice["year"]
                    + ","
                    + randomChoice["description"]
                    + "Read more @"
                    + randomChoice["wikipedia"][0]["wikipedia"]
                )
                methods["send"](info["address"], onthisday)

        except Exception as e:
            print("woops plugin error ", e)



NAME = "random_color.py"
ORIGINAL_AUTHORS = ["Jeet Trivedi"]

ABOUT = """
responds to .randcol, returns a HEX color code
"""

COMMANDS = """
>>> .randcol
returns a HEX color code: a 6-character string representing RGB
"""

WEBSITE = ""



NAME = "bitcoin.py"

ORIGINAL_AUTHORS = ["Gabriele Ron"]

ABOUT = """
Checks the current price for Bitcoin through the Legacy Coin Market Cap API
TODO: Update API to new Coin Market Cap API
"""

COMMANDS = """
>>> .btc
returns current value of bitcoin
"""

WEBSITE = "https://Macr0Nerd.github.io"



import os
import subprocess as sp
import threading
import tkinter as tk
from tkinter import *

window = tk.Tk()
window.geometry("650x670")
window.title("Manager")

current_path = os.path.split(os.path.abspath(__file__))[0]
pluginPath = os.path.join(os.sep, current_path, "plugins")
configPath = os.path.join(os.sep, current_path, "settings", "PLUGINS.conf")


def get_unique_text(text):
    uniques = sorted({i.strip() for i in text.split("\n") if i})
    uniques_text = "\n".join(uniques)
    return uniques_text


def saveFile():
    text = tt.get(1.0, END)
    unique_text = get_unique_text(text)
    with open(configPath, "w+") as f:
        f.write(get_unique_text(unique_text))
    tt.delete(1.0, END)
    tt.insert(1.0, unique_text)


def reorder():
    text = tt.get(1.0, END)
    unique_text = get_unique_text(text)
    tt.delete(1.0, END)
    tt.insert(1.0, unique_text)


def getPlugins(dirName):
    listOfFile = os.listdir(dirName)
    return listOfFile


def clicked():
    selected = [listbox.get(pos) for pos in listbox.curselection()]
    for file in selected:
        tt.insert(END, file[:-3] + "\n")


rbot_thread = ""


def run_bot():
    global rbot_thread

    def run_it():
        sp.run(["python", "run.py"])

    rbot_thread = threading.Thread(target=run_it)
    rbot_thread.start()
    runBot.config(state="disabled")
    stopBot.config(state="active")


def stop_bot():
    global rbot_thread
    rbot_thread.terminate()
    runBot.config(state="active")
    stopBot.config(state="disabled")


def exit_app(self):
    if messagebox.askokcancel("Quit", "Really quit?"):
        rbot_thread.terminate()
        window.destroy()


pluginList = getPlugins(pluginPath)

elements = [
    [
        [
            "MainLabel",
            Label(
                window,
                text=(
                    "Select the plugins you wish to                         load and add them to"
                    " the config file"
                ),
            ),
        ]
    ],
    [["listbox", Listbox(window, width=60)]],
    [["addBtn", Button(window, text="Add Plugin", width=10, command=clicked)]],
    [["label2", Label(window, text="Editable PLUGINS.conf file:")]],
    [["tt", Text(window, width=80)]],
    [["label3", Label(window, text="Don't forget to hit save!")]],
    [
        ["saveBtn", Button(window, text="Save File", width=10, command=saveFile)],
        ["reorderBtn", Button(window, text="Reorder", width=10, command=reorder)],
    ],
    [
        ["runBot", Button(window, text="RUN", width=10, command=run_bot)],
        ["stopBot", Button(window, text="STOP", width=10, command=stop_bot)],
    ],
]

for row_i, row in enumerate(elements):
    for col_i, col in enumerate(row):
        var_name = col[0]
        gui = col[1]
        _g = globals()
        _g[var_name] = gui
        if var_name in ["tt", "listbox", "addBtn"]:
            _g[var_name].grid(row=row_i, column=col_i, columnspan=2)
            window.grid_columnconfigure(col_i, weight=1, uniform="foo")
        else:
            _g[var_name].grid(row=row_i, column=col_i, sticky="NSEW")
            window.grid_columnconfigure(col_i, weight=1, uniform="foo")

tt.insert(END, open(configPath).read())

for name in pluginList:
    if name[-2:] == "py":
        listbox.insert(END, name)

window.mainloop()
window.protocol("WM_DELETE_WINDOW", exit_app)



"""
[magic_ball.py]
Magic 8 ball Plugin

[Author]
Zakaria Talhami

[About]
Fortune-telling for question using a magic 8 ball

[Commands]
>>> .8ball <<question>>
returns It is certain

>>> .magic8ball <<question>>
returns Very doubtful
"""

import random


class Plugin:
    def __init__(self):
        pass

    def answer():
        possible_answers = [
            "It is certain",
            "It is decidedly so",
            "Without a doubt",
            "Yes - definitely",
            "You may rely on it",
            "As I see it, yes",
            "Most likely",
            "Outlook good",
            "Yes",
            "Signs point to yes",
            "Reply hazy, try again",
            "Ask again later",
            "Better not tell you now",
            "Cannot predict now",
            "Concentrate and ask again",
            "Don't count on it",
            "My reply is no",
            "My sources say no",
            "Outlook not so good",
            "Very doubtful",
        ]
        return random.choice(possible_answers)

    def run(self, incoming, methods, info, bot_info):
        try:
            print("In the 8 ball area")
            msgs = info["args"][1:][0].split()
            if info["command"] == "PRIVMSG" and (msgs[0] == ".8ball" or msgs[0] == ".magic8ball"):
                question = " ".join(msgs[1:])
                if "?" in question:
                    methods["send"](info["address"], Plugin.answer())
                else:
                    methods["send"](info["address"], "You must ask a question")
        except Exception as e:
            print("woops plug", e)



"""
[conv_sniff.py]
Conversation Sniffer Plugin

[Author]
Abdur-Rahmaan Janhangeer, pythonmembers.club

[About]
senses conversation topic with sensitivity set by user, also supports
word-specific sensing
"""

import random


class Plugin:
    """
    checkin
    L checks in list
    S checks in string
    """

    def __init__(self):
        self.topics = {
            "bot": {
                "elems": ["bot", "robot", "artificial intelligence", "ai"],
                "occurs": 1,
                "replies": ["you are thinking about me and my cousins", "bots are we?"],
                "checkin": "L",
            },
            "nature": {
                "elems": ["earth", "flower", "lake", "sea", "world", "forest", "grass"],
                "occurs": 2,
                "replies": [
                    "we must remind ourselves to protect our lovely " + "planet",
                    "plant a tree when you can",
                ],
                "checkin": "L",
            },
            "alhmd": {
                "elems": ["a", "l", "ha", "m", "d"],
                "occurs": 5,
                "replies": [" yes indeed, praise be to allah (الحَمْد لله) . . ."],
                "checkin": "S",
            },
        }

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:][0].split()

            if info["command"] == "PRIVMSG":
                if len(msgs) > 1:
                    msgs = set(msgs)

                    for topic in self.topics:
                        if self.topics[topic]["checkin"] == "L":
                            meet = set(self.topics[topic]["elems"]).intersection(msgs)

                            if len(meet) == self.topics[topic]["occurs"]:
                                methods["send"](
                                    info["address"],
                                    random.choice(self.topics[topic]["replies"]),
                                )
                        elif self.topics[topic]["checkin"] == "S":
                            for word in msgs:
                                meet = set(self.topics[topic]["elems"]).intersection(set(word))
                                occurs = self.topics[topic]["occurs"]
                                if meet and len(meet) > occurs - 2:
                                    methods["send"](
                                        info["address"],
                                        random.choice(self.topics[topic]["replies"]),
                                    )
                                    break

        except Exception as e:
            print("\n*error*\nwoops plugin", __file__, e, "\n")



import emoji


class Plugin:
    def __init__(self):
        pass

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:][0].split()
            print(len(msgs))
            if info["command"] == "PRIVMSG" and msgs[0] == ".emoji":
                meaning = emoji.demojize(str(msgs[1]))
                methods["send"](info["address"], meaning)
        except Exception as e:
            print("woops plugin error ", e)



""" deck class """

# pylint: disable=E1601, W0612

import random

import card


class Deck:
    """deck class"""

    colors = ["C", "D", "H", "S"]
    figures = ["2", "3", "4", "5", "6", "7", "8", "9", "T", "J", "Q", "K", "A"]

    i = 0
    for color in colors:

        for figure in figures:

            locals()["card%s" % i] = card.Card(figure + color)
            i += 1

    def __init__(self):
        """deck initialization"""

        self.__deck = []
        for color in self.colors:

            for figure in self.figures:

                self.__deck.append(card.Card(figure + color))

    def show_deck(self):
        """show deck"""

        return " ".join([c.show_card() for c in self.__deck])

    def nth_card(self, n):
        """show the n-th card from deck"""

        try:
            return self.__deck[n]
        except BaseException:
            print("Wrong index")
            return card.Card("0X")

    def draw_by_number(self, nr):
        """pick card from deck by nr"""

        try:
            pick = self.__deck[nr]
            if pick == "OX":
                raise BaseException
            self.__deck.remove(pick)
            return pick

        except BaseException:
            print("Wrong index")
            return card.Card("0X")

    def draw_by_name(self, name):
        """pick card from deck by name"""

        flag = 0
        for pick in self.__deck:

            if pick.show_card() == name:
                self.__deck.remove(pick)
                flag = 1
                break

        if flag == 0:
            print("Wrong name")
            pass

        else:
            return pick

    def make_board(self):
        """make a random board"""

        board = []
        for i in range(5):

            random_number = random.randint(0, len(self.__deck) - 1)
            board.append(self.draw_by_number(random_number))

        return board

    def make_hand(self):
        """make a random hand"""

        hand = []
        for i in range(2):

            random_number = random.randint(0, len(self.__deck) - 1)
            hand.append(self.draw_by_number(random_number))

        return hand

    def draw_random_card(self):
        """draw a random card"""

        random_number = random.randint(0, len(self.__deck) - 1)
        return self.draw_by_number(random_number)

    def __len__(self):
        """return the number of cards in the deck"""
        return len(self.__deck)



NAME = "mail.py"
ORIGINAL_AUTHORS = ["Tanner Fry"]

ABOUT = """
Will allow the user to send an email while in the chat
with the bot. The text send will be interpreted as html
so you can use formatting such as <br> to make new lines,
and any other html formatting commands in the text of the
body of the email. No additional libraries need to be installed.
Make sure that you configure the email_config.conf file with your
email, your email password, SMTP server, and SMTP server port.
See that document for more information.
"""

COMMANDS = """
.mail <To email address> .body <Text for the body of your email>
 .subject <Text of subject for email>
EX:// ".mail test@email.com .body testing body for honeybot email
 .subject testing subject"
"""

WEBSITE = ""



"""
[username.py]
Username Generator Plugin

[Author]
Abdur-Rahmaan Janhangeer, pythonmembers.club

[About]
generates random usernames, used for inspiration

[Commands]
>>> .uname
returns generated username
"""
import random


class Plugin:
    def __init__(self):
        pass

    def gen_uname(self):
        """
        Return a string containing a randomly-generated username based
        on an adjectives list (p1) and a noun list (p2)
        """
        p1 = [
            "hopeful",
            "young",
            "sloppy",
            "magic",
            "intelligent",
            "uncommon",
            "cute",
            "dangerousinnocent",
            "spooky",
            "crazy",
            "young",
            "desperate",
            "epic",
            "anonymous",
            "acceptable",
            "achievable",
            "active",
            "active",
            "active",
            "additional",
            "adjustable",
            "admirable",
            "advisable",
            "massive",
            "amazing",
            "amusing",
            "annoying",
            "approachable",
            "attentive",
            "attractive",
            "avoidable",
            "believable",
            "black",
            "bloody",
            "boring",
            "bothering",
            "breathing",
            "buried",
            "careful",
            "challenging",
            "chasing",
            "cheerful",
            "chosen",
            "clear",
            "collective",
            "comfortable",
            "complex",
            "confused",
            "considerable",
            "consoled",
            "continuous",
            "crazy",
            "creative",
            "creditable",
            "curable",
            "cursed",
            "damaged",
            "deaf",
            "decisive",
            "decorative",
            "delightful",
            "demanding",
            "derivative",
            "deserving",
            "destructive",
            "developing",
            "dead",
            "different",
            "disturbing",
            "dusty",
            "educative",
            "embarrassing",
            "powerful",
            "empty",
            "circular",
            "courageous",
            "dangerous",
            "enthusiastic",
            "numerable",
            "envious",
            "evaporating",
            "expected",
            "explainable",
            "exploring",
            "fascinating",
            "",
            "firm",
            "flying",
            "forceful",
            "glorious",
            "growing",
            "harmful",
            "hateful",
            "healthy",
            "hopeful",
            "indentified",
            "indentifying",
            "imitative",
            "impressive",
            "inclusive",
            "indicative",
            "informative",
            "inhabitant",
            "injurious",
            "inquiring",
            "instructive",
            "insulting",
            "intentional",
            "interfering",
            "introductory",
            "inventive",
            "irritating",
            "leading",
            "lively",
            "alive",
            "lively",
            "lost",
            "mad",
            "migrating",
            "modern",
            "moistures",
            "monotonous",
            "movable",
            "narrow",
            "national",
            "observatory",
            "own",
            "performing",
            "permissible",
            "persuasive",
            "pleasant",
            "popular",
            "quick",
            "red",
            "sad",
            "secured",
            "scenic",
            "seen",
            "speedy",
            "white",
            "bad",
        ]
        p2 = [
            "star",
            "tree",
            "ant",
            "spider",
            "moon",
            "bug",
            "name",
            "heisenberg",
            "dragonsnake",
            "lion",
            "rebel",
            "patriot",
            "flower",
            "popsicle",
            "sun",
            "failure",
            "apple",
            "arm",
            "banana",
            "bike",
            "bird",
            "book",
            "chin",
            "clam",
            "class",
            "clover",
            "club",
            "corn",
            "crayon",
            "crow",
            "crown",
            "crowd",
            "crib",
            "desk",
            "dime",
            "dirt",
            "dress",
            "fang",
            "field",
            "flag",
            "flower",
            "fog",
            "game",
            "heat",
            "hill",
            "home",
            "horn",
            "hose",
            "joke",
            "juice",
            "kite",
            "lake",
            "maid",
            "mask",
            "mice",
            "milk",
            "mint",
            "meal",
            "meat",
            "moon",
            "mother",
            "morning",
            "name",
            "nest",
            "nose",
            "pear",
            "pen",
            "pencil",
            "plant",
            "rain",
            "river",
            "road",
            "rock",
            "room",
            "rose",
            "seed",
            "shape",
            "shoe",
            "shop",
            "show",
            "sink",
            "snail",
            "snake",
            "snow",
            "soda",
            "sofa",
            "star",
            "step",
            "stew",
            "stove",
            "straw",
            "string",
            "summer",
            "swing",
            "table",
            "tank",
            "team",
            "tent",
            "test",
            "toes",
            "tree",
            "vest",
            "water",
            "wing",
            "winter",
            "woman",
            "women",
        ]
        return f"{random.choice(p1)}{random.choice(p2)}"

    def run(self, incoming, methods, info, bot_info):
        try:
            # if '!~' in info['prefix']:
            # print(info)
            msgs = info["args"][1:]
            if info["command"] == "PRIVMSG" and msgs[0] == ".uname":
                methods["send"](info["address"], Plugin.gen_uname(self))
        except Exception as e:
            print("woops plug", e)



"""
[fact.py]
Fact Plugin

[Author]
Justin Walker

[About]
Returns a random fact.
Facts sourced from Mental Floss
http://mentalfloss.com/article/55443/101-amazing-facts

[Commands]
>>> .fact
returns random fact
"""

import random


class Plugin:
    def __init__(self):
        pass

    def __fact():
        return random.choice(FACT_LIST)

    def run(self, incoming, methods, info, bot_info):
        try:
            if info["command"] == "PRIVMSG" and info["args"][1] == ".fact":
                methods["send"](info["address"], Plugin.__fact())
        except Exception as e:
            print("woops plugin error: ", e)


FACT_LIST = [
    "On Good Friday in 1930, the BBC reported, 'There is no news.' "
    + "Instead, they played piano music."
    "Amelia Earhart and Eleanor Roosevelt once sneaked out of a White"
    + "House event, commandeered an airplane, and went on a joyride to Baltimore."
    "The 100 folds in a chef's toque are said to represent 100 ways "
    + "to cook an egg.The world’s oldest surviving piano is at the Metropolitan Museum of Art "
    + "in New York City. The instrument dates back to 1720, and was made by "
    + "an Italian man named Bartolomeo Cristofori."
    "The modern popped collar originated as a way to keep tennis players’"
    + "necks from getting sunburnt."
    "In 2006, an Australian man tried to sell New Zealand on Ebay. The "
    + "price reached $3,000 before it was shut down.",
    "Google's founders were willing to sell to excite for under $1 million"
    + " in 1999--but excite turned them down.",
    "There was a third Apple founder. Ronald Wayne sold his 10% stake " + "for $800 in 1976.",
    "Reed Hastings was inspired to start Netflix after racking up a "
    + "$40 late fee on a VHS copy of Apollo 13.",
    "During WWI, German measles were called 'Liberty Measles' and "
    + "dachshunds became 'liberty hounds.'",
    "A 2009 search for the loch ness monster came up empty. "
    + "Scientists did find over 100,000 golf balls.",
    "In Japan, letting a sumo wrestler make your baby cry is considered " + "good luck.",
    "When three-letter airport codes became a standard, airports that "
    + "been using two letters simply added an X.",
    "The actor who was inside R2-D2 hated the guy who played C-3PO, "
    + "calling him the 'The rudest man I've ever met.'",
    "At one point in the 1990's, 50% of all CD's produced worldwide" + "were for AOL.",
    "Toy companies failed to duplicate the success of Theodore "
    + "Roosevelt's Teddy Bear with William Taft's 'Billy Possum.'",
    "Nutella was invented during WWII, when an Italian pastry maker "
    + "mixed hazelnuts into chocolate to extend his chocolate ration.",
    "In response to 'The Lorax', the forest products industry published "
    + "'Truax' to teach kids the importance of logging.",
    "Tsutomu Yamaguchi was in Hiroshima for work when the first A-Bomb "
    + "hit, make it home to Nagasaki for the second, and lived to be 93.",
    "A British man changed his name to Tim PPPPPPPPPPrice to make it "
    + "harder for telemarketers to pronounce.",
    "J.P. Morgan once offered $100,000 to anyone who could figure out why"
    + "his face was so red. No one solved the mystery.",
    "Prairie dogs say hello with kisses.",
    "Before settling on the Seven Dwarfs we know today, Disney "
    + "considered Chesty, Tubby, Burpy, Deafy, Hickey, Wheezy, and Awful.",
    "New Mexico State's first graduating class in 1893 had only one "
    + "student - and he was shot and killed before graduation.",
    "Jonas Salk declined to patent his Polio Vaccine. 'There is no "
    + "patent,' he said. 'Could you patent the sun?'",
    "The 50-star American Flag was designed by and Ohio High School "
    + "student for a class project. His teacher originally gave him "
    + "a B-.",
    "Sean Connery turned down the Gandalf role in 'The Lord of the "
    + "Rings'. 'I read the book. I read the script. I saw the movie. "
    + "I still don't understand it.",
    "Chock Full O'Nuts Coffee does not contain nuts. It's named for a "
    + "chain of nut stores that the founder converted into coffee shops.",
    "12+1 = 11+2, and 'Twelve plus one' is an anagram of 'eleven plus " + "two'.",
    "At the height of Rin Tin Tin's fame, a chef prepared him a daily "
    + "steak lunch. Classical musicians played to aid his digestion.",
    "The Arkansas school for the Deaf's nickname is the Leopards. The " + "Deaf Leopards.",
    "If your dog's feet smell like corn chips, you're not alone. The term"
    + "'Frito feet' was coined to describe the scent.",
    "Barry Manilow did not write his hit 'I Write the Songs'.",
    "Barry Manilow wrote State Farm's 'Like a Good Neighbor' jingle.",
    "Winston Churchill's mother was born in Brooklyn.",
    "Officials in Portland, OR, drained 8 million gallons of water from "
    + "a resevoir in 2011 because a buzzed 21-year-old peed in it.",
    "There's a basketball court above the supreme court. It's known as "
    + "the highest court in the land.",
    "The medical term for ice cream headaches is Sphenopalatine " + "Ganglioneuralgia.",
    "After Leonardo Da Vinci's death, King Francis I of France hung "
    + "the 'Mona Lisa' in his bathroom.",
    "Redondo Beach, CA adopted the Goodyear Blimp as the cit's official " + "bird in 1983.",
    "In 2001, Beaver College changed its name to Arcadia in part because "
    + "anti-porn filters blocked access to the school's website.",
    "Quentin Tarantino played an Elvis impersonator on 'The Golden Girls'.",
    "Wendy's founder Dave Thomas dropped out of high school but picked "
    + "up his GED in 1993. His GED class voted him most likely to succeed.",
    "Sleeping through winter is hibernation, while sleeping through " + "summer is estivation.",
    "In Qaddafi's compound, Libyan rebels found a photo album filled "
    + "with pictures of Condoleezza Rice.",
    "Marie Curie's notebooks are still radioactive. Researchers hoping "
    + "to view them must sign a disclaimer.",
    "William McKinley was on the $500 bill, Grover Cleveland was on the "
    + "$1,000, and James Madison was on the $5,000.",
    "In 1999, the U.S. government paid the Zapruder family $16 million "
    + "for the film of JFK's assassination.",
    "Janis Joplin left $2,500 in her will for her friends to 'Have a " + "ball after I'm gone.",
    "In the mid-1960's, Slumber Party Barbie came with a book called "
    + "'How to Lose Weight.' One of the tips was 'Don't Eat.'",
    "Ben & Jerry originally considered getting into the bagel business, "
    + "but the equipment was too expensive.",
    "The first webcam watched a coffee pot. It allowed researchers at "
    + "Cambridge to monitor the coffee situation without leaving their "
    + "desks.",
    "The last time a Republican was elected President without a Nixon or "
    + "Bush on the ticket was 1928.",
    "In 1979, Japan offered new British PM Margaret Thatcher 20 'Karate "
    + "Ladies' for protection at an economic summit. She declined.",
    "Before Google launched Gmail, 'G-Mail' was the name of a free email "
    + "service offered by Garfield's website.",
    "The final speech by Gregory Peck in 'To Kill a Mockingbird' was " + "done in one take.",
    "In 1980, Detroit presented Saddam Hussein with a key to the city.",
    "Crayola means 'oily chalk.' The name combines 'craie' (French for "
    + "'chalk') and 'ola'(short for 'oleaginous,' or 'oily').",
    "Bob Ross on his Air Force career. 'I was the guy who makes you "
    + "scrub the latrine... Who screams at you for being late to work.",
    "In 1973, Mao Zedong told Henry Kissinger that China had an excess "
    + "of females and offered the U.S. 10 million Chinese woman.",
    "Play-Doh started out as a wallpaper cleaner before the head of the "
    + "struggling company realized the non-toxic material made a good "
    + "modeling clay for children and rebranded it.",
    'Another term for the hashtag or pound sign is "octothorpe".',
    "If you start counting at one and spell out the numbers as you go, "
    + "you won't use the letter A until you reach 1,000.",
    "In Spain, Mr. Clean is known as Don Limpio.",
    "In a 2008 survey, 58% of British teens thought Sherlock Holmes was "
    + "a real guy, while 20% thought Winston Churchill was not.",
    "Fredric Baur invented the Pringles can. When he passed away in 2008, "
    + "his ashes were buried in one.",
    "Italy has the most UNECO sites in the world",
    "Space is completly silent",
    "The sunset on Mars appears blue",
    'In the early drafts of "Star Wars: The Empire Strikes Back", ' + "Yoda was named Buffy.",
]



NAME = "roll.py"
ORIGINAL_AUTHORS = ["Glenn Toms"]

ABOUT = """
Will roll dice in the form of 1d4, 10d6 and return total.
"""

COMMANDS = """
>>> .roll <<dice>>
returns Total of dice
"""

WEBSITE = ""



"""
[riddle.py]
Riddle Plugin

[Author]
Angelo Giacco

[About]
Returns a riddle or whether guess at the answer was correct or not.

[Commands]
>>> .riddle
returns a random riddle

.riddle guess <<attempt>>
returns whether the guess was correct or wrong
"""
import random


class Plugin:
    def __init__(self):
        pass

    def get_riddle(self, command="show", words=""):
        if command == "show":
            self.r = Riddle()
            message = self.r.riddle
            return message
        elif command == "guess":
            try:
                message = self.r.guess_answer(words)
                self.r = None
                return message
            except Exception:
                return "first create a riddle by entering .riddle"
        else:
            return "riddle plugin error"

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:][0].split()
            print(msgs)
            if info["command"] == "PRIVMSG" and msgs[0] == ".riddle":
                if len(msgs) >= 3:
                    if msgs[1] == "guess":
                        attempt = " ".join(msgs[2:])
                        methods["send"](info["address"], Plugin.get_riddle(self, "guess", attempt))
                elif len(msgs) == 1:
                    methods["send"](info["address"], Plugin.get_riddle(self))

        except Exception as e:
            print("Error with riddle plugin", e)


class Riddle:
    def __init__(self):
        print("create riddle")
        self.riddles_dict = {
            "The more you have of it, the less you see. What is it?": "darkness",
            "What has a head, a tail, is brown, and has no legs?": "a penny",
            "What English word has three consecutive double letters?": "ookkeeper",
            "I know a word of letters three. Add two, and fewer there will be!": "few",
            "Two in a corner, 1 in a room, 0 in a house," + " but 1 in a shelter. What am I?": "r",
            "What starts with a T, ends with a T, and has T in it?": "a teapot",
            "What happens when you throw a yellow rock into a purple stream?": "a splash",
            "Say my name and I disappear. What am I?": "silence",
            "What is it that after you take away the whole," + " some still remains?": "wholesome",
            "A box without hinges, lock or key, yet golden treasure lies within."
            + " What is it?": "an egg",
            "Forward I’m heavy, but backwards I’m not. What am I?": "ton",
            "I am a box that holds keys without locks,"
            + " yet they can unlock your soul. What am I?": "a piano",
            "What gets wetter as it dries?": "a towel",
            "I’m full of holes, yet I’m full of water. What am I?": "a sponge",
            "What question can you never honestly answer yes to?": "asleep",
            "What has a neck and no head, two arms but no hands?": "a shirt",
            "Feed me and I live, give me drink and I die. What am I?": "a fire",
            "A man went to the hardware store to buy items for his house."
            + " 1 would cost $.25, 12 would cost $.50, 122 would cost $.75."
            + " What was he buying?": "house numbers",
            "What is a thing that the more you take," + " the more you leave behind?": "footsteps",
            "Remove six letters from this sequence to reveal"
            + " a familiar English word. BSAINXLEATNTEARS": "banana",
        }
        self.riddle = random.choice(list(self.riddles_dict.keys()))

    def guess_answer(self, guess):
        if guess.lower() == self.riddles_dict[self.riddle]:
            message = guess + " is correct!"
        else:
            message = guess + " is wrong! The correct answer is " + self.riddles_dict[self.riddle]
        return message



""" pot class """

# pylint: disable=E1601


class Pot:
    """pot class"""

    def __init__(self):
        """pot initialization"""

        self.__pot = 0

    def show_pot(self):
        """show pot"""

        return self.__pot

    def increase_pot(self, chips):
        """increase pot"""

        self.__pot = self.__pot + chips
        return self.__pot



NAME = "calc.py"
ORIGINAL_AUTHORS = ["Abdur-Rahmaan Janhangeer, pythonmembers.club"]

ABOUT = """
evaluates maths expressions in the format supported by py
"""

COMMANDS = """
>>> .calc <maths expression>
returns evaluated expression
"""

WEBSITE = ""



"""
[translate.py]
Translate Plugin

[Author]
Ahmed Deeb

[About]
A Google Translate plugin

[Commands]
>>> . Google Translator object.

    Examples
    --------
    translator = Plugin()

    results1 = translator.translate("Einen schönen Tag allerseits")

    # try 2 at a time
    results2 = translator.translate(["Einen schönen Tag allerseits",
                                     "Ich nehme an"])

    # try detect
    results3 = translator.detect("Einen schönen Tag allerseits")

    # try to detect 2 at a time
    results4 = translator.detect(["Einen schönen Tag allerseits",
                                     "Ich nehme an"])

You need to fill in your API key from google below. Note that querying
supported languages is not implemented.

Language Code
-------- ----
Afrikaans 	af
Albanian 	sq
Arabic  	ar
Belarusian 	be
Bulgarian 	bg
Catalan 	ca
Chinese Simplified 	    zh-CN
Chinese Traditional 	zh-TW
Croatian 	hr
Czech 	    cs
Danish  	da
Dutch   	nl
English 	en
Estonian 	et
Filipino 	tl
Finnish 	fi
French 	    fr
Galician 	gl
German  	de
Greek 	    el
Hebrew 	    iw
Hindi 	    hi
Hungarian 	hu
Icelandic 	is
Indonesian 	id
Irish 	    ga
Italian 	it
Japanese 	ja
Korean  	ko
Latvian 	lv
Lithuanian 	lt
Macedonian 	mk
Malay   	ms
Maltese 	mt
Norwegian 	no
Persian 	fa
Polish  	pl
Portuguese 	pt
Romanian 	ro
Russian 	ru
Serbian 	sr
Slovak 	    sk
Slovenian 	sl
Spanish 	es
Swahili 	sw
Swedish 	sv
Thai 	    th
Turkish 	tr
Ukrainian 	uk
Vietnamese 	vi
Welsh 	    cy
Yiddish 	yi
"""

import gzip
import json
import os.path
import urllib.parse
from urllib.request import (
    HTTPDefaultErrorHandler,
    HTTPError,
    HTTPRedirectHandler,
    build_opener,
    urlparse,
)

from httplib2 import FileCache, Http

# Hard-coded variables ###

api = "YOUR-API-KEY-GOES-HERE"

languages = [
    "af",
    "sq",
    "ar",
    "be",
    "bg",
    "ca",
    "zh-CN",
    "zh-TW",
    "hr",
    "cs",
    "da",
    "nl",
    "en",
    "et",
    "tl",
    "fi",
    "fr",
    "gl",
    "de",
    "el",
    "iw",
    "hi",
    "hu",
    "is",
    "id",
    "ga",
    "it",
    "ja",
    "ko",
    "lv",
    "lt",
    "mk",
    "ms",
    "mt",
    "no",
    "fa",
    "pl",
    "pt",
    "ro",
    "ru",
    "sr",
    "sk",
    "sl",
    "es",
    "sw",
    "sv",
    "th",
    "tr",
    "uk",
    "vi",
    "cy",
    "yi",
]


def _validate_language(lang):
    if lang in languages:
        return True
    return False


# Custom G-Zipped Cache #


def save_cached_key(path, value):
    f = gzip.open(path, "wb")
    f.write(value)
    f.close()


def load_cached_key(key):
    f = gzip.open(key)
    retval = f.read()
    f.close()
    return retval


class ZipCache(FileCache):
    def __init__(self, cache=".cache"):  # TODO: allow user configurable?
        super().__init__(cache)

    def get(self, key):
        cacheFullPath = os.path.join(self.cache, self.safe(key))
        retval = None
        try:
            retval = load_cached_key(cacheFullPath)
        except OSError:
            pass
        return retval

    def set(self, key, value):
        retval = None
        cacheFullPath = os.path.join(self.cache, self.safe(key))
        save_cached_key(cacheFullPath, value)


# Error Handlers #


class DefaultErrorHandler(HTTPDefaultErrorHandler):
    def http_error_default(self, req, fp, code, msg, headers):
        result = HTTPError(req.get_full_url(), code, msg, headers, fp)
        result.status = code
        return result


class RedirectHandler(HTTPRedirectHandler):
    def http_error_301(self, req, fp, code, msg, headers):
        result = HTTPRedirectHandler.http_error_301(self, req, fp, code, msg, headers)
        result.status = code
        return result

    def http_error_302(self, req, fp, code, msg, headers):
        result = HTTPRedirectHandler.http_error_302(self, req, fp, code, msg, headers)
        result.status = code
        return result


# Translator Class #


class Plugin:
    """
    Google Translator object.

    Examples
    --------
    translator = Plugin()

    results1 = translator.translate("Einen schönen Tag allerseits")

    # try 2 at a time
    results2 = translator.translate(["Einen schönen Tag allerseits",
                                     "Ich nehme an"])

    # try detect
    results3 = translator.detect("Einen schönen Tag allerseits")

    # try to detect 2 at a time
    results4 = translator.detect(["Einen schönen Tag allerseits",
                                     "Ich nehme an"])
    """

    def __init__(self):
        # NOTE: caching is done on etag not expiry
        self.cache_control = "max-age=" + str(7 * 24 * 60 * 60)
        self.connection = Http(ZipCache())
        self._opener = build_opener(DefaultErrorHandler, RedirectHandler)
        self.base_url = "https://www.googleapis.com/language/translate/v2/"

    def _urlencode(self, params):
        """
        Rewrite urllib.urlencode to handle string input verbatim
        """
        params = "&".join(map("=".join, params))
        return params

    def _build_uri(self, extra_url, params):
        params = [("key", api)] + params
        params = self._urlencode(params)
        url = f"{urlparse.urljoin(self.base_url, extra_url)}?{params}"
        if len(url) > 2000:  # for GET requests only, POST is 5K
            raise ValueError("Query is too long. URL can only be 2000 characters")
        return url

    def _fetch_data(self, url):
        connection = self.connection
        resp, content = connection.request(
            url, headers={"user-agent": api, "cache-control": self.cache_control}
        )
        # DEBUG
        # if resp.fromcache:
        #   print "Using from the cache"
        return content

    def _sanitize_query(self, query):
        if isinstance(query, (list, tuple)):
            query = zip("q" * len(query), map(urllib.quote, query))
        else:
            query = [("q", urllib.quote(query))]
        return query

    def _decode_json(self, response):
        """
        Assumes that response only holds one result
        """
        json_data = json.loads(response)
        try:
            data = json_data["data"]
            if "translations" in data:
                return data["translations"]
            elif "detections" in data:
                return data["detections"]
        except Exception:
            if "error" in json_data:
                return json_data["error"]

    def detect(self, query):
        """
        Try to detect the language of a word, phrase, or list of either.

        Parameters
        ----------
        query : str or iterable
            Query or list of queries to translate

        Returns
        -------
        List of dictionaries for each query
        """
        query = self._sanitize_query(query)
        url = self._build_uri(extra_url="detect/", params=query)
        content = self._fetch_data(url)
        # going to have json, decode it first
        return self._decode_json(content)

    def translate(self, query, target="en", source="", _dirty=False):
        """
        Translate a query.

        Parameters
        ----------
        query : str or iterable
            Query or list of queries to translate
        target : str
            Language to translate into.
        source : str, optional
            Language of the source text, if known. Will be auto-detected
            if an empty string is passed.
        dirty : bool
            This is not intended to be used by users. It is here to avoid
            infinite recursion if the query returns an error because the
            language can't be detected.

        Returns
        -------
        List of dictionaries for each query

        Notes
        -----
        If the language can't be detected for a word an attempt is made
        to detect the language of the word and resubmit the query. If a
        list of words to translate is given and an error is encountered,
        it is assumed that the list of words all have the same source language
        when resubmitted.
        """
        try:
            assert _validate_language(target)
        except ValueError:
            raise ValueError("target language %s is not valid" % target)
        newquery = self._sanitize_query(query)
        params = [("key", api), ("target", target)]
        if source:
            try:
                assert _validate_language(target)
            except ValueError:
                raise ValueError("source language %s is not valid" % target)
            params += ["source", source]
        params += newquery
        url = self._build_uri("", params)
        content = self._fetch_data(url)
        results = self._decode_json(content)

        if "errors" in results and not _dirty:
            if results["message"] == "Bad language pair: {0}":
                # try to detect language and resubmit query
                source = self.detect(query)
                source = source[0]["language"]
                return self.translate(query, target, source, True)

        return results


if __name__ == "__main__":
    do_run = input("Running this costs money. Key 1 to continue: ")
    if int(do_run) != 1:
        raise ValueError("Exiting")
    translator = Plugin()

    results1 = translator.translate("Einen schönen Tag allerseits")

    # try 2 at a time
    # results2 = translator.translate(["Einen schönen Tag allerseits",
    #                                 "Ich nehme an"])

    # try detect
    # results3 = translator.detect("Einen schönen Tag allerseits")

    # try 2 at a time
    # results4 = translator.detect(["Einen schönen Tag allerseits",
    #                                 "Ich nehme an"])



# black inspired
import os
import sys

from setuptools import find_packages, setup

if not (sys.version_info.major == 3 and sys.version_info.minor >= 7 and sys.version_info.micro >= 0): 
    raise Exception("honeybot requires Python 3.7.0 at least")

from pathlib import Path  # noqa E402

CURRENT_DIR = Path(__file__).parent
sys.path.insert(0, str(CURRENT_DIR))  # for setuptools.build_meta


try:
    from src.honeybot import __version__
except Exception as e:
    pass


def get_long_description() -> str:
    return (
        (CURRENT_DIR / "README.md").read_text(encoding="utf8")
    )

if sys.argv[-1] == "publish":  # requests
    os.system("python setup.py sdist")  # bdist_wheel
    os.system("twine upload dist/* --skip-existing")
    sys.exit()

setup(
    name="honeybot",
    version=__version__,
    description="IRC bot with vast collection of plugins. First timers friendly",
    long_description=get_long_description(),
    long_description_content_type="text/markdown",
    keywords="irc bot plugins",
    author="Abdur-Rahmaan Janhnageer",
    author_email="arj.python@gmail.com",
    url="https://github.com/pyhoneybot/honeybot",
    project_urls={"Changelog": "https://github.com/pyhoneybot/honeybot/blob/main/CHANGES.md"},
    license="MIT",
    py_modules=[],
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    package_data={
        "honeybot": ["settings/*.conf", "*.txt", "*.toml"]
    },
    python_requires=">=3.7.0",
    zip_safe=False,
    install_requires=[
        "tomli>=2.0.0"
    ],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3 :: Only",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    entry_points={
        "console_scripts": [
            "honeybot=honeybot.manage:main",
        ]
    },
)



"""
[calc.py]
Maths Operation Plugin

[Author]
Abdur-Rahmaan Janhangeer, pythonmembers.club

[About]
evaluates maths expressions in the format supported by py

[Commands]
>>> .calc <maths expression>
returns evaluated expression
"""
from math import *


class Plugin:
    def __init__(self):
        pass

    @staticmethod
    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:][0].split()

            if info["command"] == "PRIVMSG" and len(msgs) > 1 and msgs[0] == ".calc":
                safe_dict = {
                    "acos": acos,
                    "asin": asin,
                    "atan": atan,
                    "atan2": atan2,
                    "ceil": ceil,
                    "cos": cos,
                    "cosh": cosh,
                    "degrees": degrees,
                    "e": e,
                    "exp": exp,
                    "fabs": fabs,
                    "floor": floor,
                    "fmod": fmod,
                    "frexp": frexp,
                    "hypot": hypot,
                    "ldexp": ldexp,
                    "log": log,
                    "log10": log10,
                    "modf": modf,
                    "pi": pi,
                    "pow": pow,
                    "radians": radians,
                    "sin": sin,
                    "sinh": sinh,
                    "sqrt": sqrt,
                    "tan": tan,
                    "tanh": tanh,
                }
                expr = msgs[1]
                methods["send"](
                    info["address"],
                    "{}".format(eval(expr, {"__builtins__": None}, safe_dict)),  # nosec eval_used
                )
        except Exception as ex:
            print("woops plugin", __file__, ex)



"""
[hangman.py]
Hangman Game Plugin

[Author]
Justin Walker

[About]
Plays game of hangman

[Commands]
>>> .hangman start
Starts hangman game and returns game screen.

>>> .hangman guess <<word or letter>>
Submits word or letter guess and returns game screen.
"""

import random


class Plugin:
    def __init__(self):
        pass

    # __hangman allows the plugin to call the hangman class and sends input to the
    # game. Detects which command is entered, either 'start' or 'guess', and if
    # guess is followed by a single char or entire word. Error displayed upon
    # incorrect command.

    def hangman(self, command, word):
        msg = "Command entered incorrectly."
        if command.lower() == "start":
            self.class_hangman = Hangman()
            msg = (
                "Welcome to hangman! "
                + "You may use command 'start' to start new game  "
                + "or 'guess ---' with a word or letter to play."
                + self.class_hangman.display_screen()
            )
        elif command.lower() == "guess":
            if len(word.strip()) > 1:
                self.class_hangman.guess_word(word)
                msg = self.class_hangman.display_screen()
            elif len(word.strip()) == 1:
                self.class_hangman.guess_letter(word)
                msg = self.class_hangman.display_screen()
        return msg

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:][0].split()
            if info["command"] == "PRIVMSG":
                if len(msgs) > 1:
                    if msgs[0] == ".hangman":
                        command = msgs[1]
                        word = ""
                        if len(msgs) > 2:
                            word = msgs[2]
                        methods["send"](info["address"], Plugin.hangman(self, command, word))
        except Exception as e:
            print("woops plugin error", e)


class Hangman:
    def __init__(self):
        self.wordChoices = [
            "pig",
            "candy",
            "nerve",
            "shocking",
            "eating",
            "werewolf",
            "blouse",
            "bloom",
            "coward",
            "crafty",
            "doctor",
            "container",
            "cursed",
            "convertible",
            "beaver",
            "biblical",
            "arsonist",
            "victory",
            "loneliness",
            "blowgun",
            "spider",
            "federal",
            "analysis",
            "reverse",
            "horizontal",
            "martini",
            "bleeder",
            "ammonia",
            "biplane",
            "bless",
            "crusher",
            "hippo",
            "americana",
            "ambient",
            "blinking",
            "vibrator",
            "apocalypse",
            "appetite",
            "baptism",
            "calculation",
            "knuckle",
            "formula",
            "robbery",
            "basement",
            "decadence",
            "fright",
            "jigsaw",
            "guidebook",
            "robotic",
            "arrogant",
            "acrobat",
            "weasel",
            "blueberry",
            "anybody",
            "propeller",
            "wolves",
            "crystal",
            "flamethrower",
            "breakwater",
            "discontent",
            "creation",
            "academic",
            "downfall",
            "peach",
            "cunning",
            "atonement",
            "tongue",
            "academy",
            "vaccant",
            "family",
            "brave",
            "adaptive",
            "insane",
            "crayon",
            "healing",
            "ghoul",
            "abandon",
            "robotic",
            "plasma",
            "hidden",
        ]
        randIndex = random.randint(0, len(self.wordChoices) - 1)
        self.gameWord = self.wordChoices[randIndex]
        print(self.gameWord)
        self.display = "-" * len(self.gameWord)
        self.guessCount = len(self.display) + 3
        self.display_message = f" You have {self.guessCount} guesses remaining."
        self.endGame = False
        self.endMessage = "You shouldn't be able to see this."

    # guess_letter is used when user enters a single character guess.

    def guess_letter(self, guessLetter):
        # First find at which indeces the guessed letter is in the word.

        indeces = []
        index = 0
        newWord = ""
        for letter in self.gameWord:
            if guessLetter.lower() == letter:
                indeces.append(index)
            index += 1

        # Form new word with - for incorrect letter and add in correct letter
        # at found indeces

        for tracker in range(len(self.display)):
            if len(indeces) > 0 and indeces[0] == tracker:
                indeces.pop(0)
                newWord += guessLetter
            elif self.display[tracker] != "-":
                newWord += self.display[tracker]
            else:
                newWord += "-"

        self.display = newWord
        self.check_win()

    # guess_word is for when user tries to guess the complete word.

    def guess_word(self, wordGuess):
        if wordGuess.lower() == self.gameWord:
            self.display = self.gameWord
            self.check_win()
        else:
            self.display_message = (
                f"'{wordGuess}' was incorrect. " + f"You have {self.guessCount} guesses remaining."
            )

    # check_win determines if the user has guessed the entire word after each
    # guess. If the user hasn't won, they lost one of their guesses.

    def check_win(self):
        win = True
        for letter in self.display:
            if letter == "-":
                win = False

        if win is True:
            self.display = f"'{self.gameWord}' is correct. You win!"
            self.display_message = (
                f" You had {self.guessCount} guesses remaining."
                + "\nUse 'start' command to try again."
            )
            self.endGame = True
            self.endMessage = self.display + self.display_message
        else:
            self.decrement_guesses()

    # decrement_guesses reduces the players guessCount and declares loss if the
    # count reaches 0.

    def decrement_guesses(self):
        self.guessCount -= 1
        if self.guessCount == 0:
            self.endMessage = (
                "You have no more guesses.\n"
                + f"The correct word was '{self.gameWord}'.\n"
                + "You lose. Use start command to try again"
            )
            self.endGame = True
        else:
            self.display_message = f" You have {self.guessCount} guesses remaining."

    # display_screen is to output what the user should see in the game's current
    # state.

    def display_screen(self):
        if self.endGame is False:
            return self.display + self.display_message
        else:
            return self.endMessage


def send(info, message):
    print(message)


def test_them(plugin, msg):

    methods = {"send": send}
    msg = msg
    info = {"args": [None, msg], "command": "PRIVMSG", "address": "That place"}
    plugin.run("", methods, info)



NAME = "corona.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
provides information about the coronavirus pandemic
"""

COMMANDS = """
>>> .corona
returns global coronavirus information

.corona <<country>>
returns coronavirus information for a specific country
"""

WEBSITE = ""



"""
[send_message.py]
Send Message Plugin

[Author]
Justin Walker

[About]
Sends a message to another channel.

[Commands]
>>> .send #channel .u riceabove .m how are you?
Sends a message to #channel like
'IronPenguin from #channel says to riceabove: how are you?'

>>> .send #channel hi all
Sends a message to #channel like
'IronPenguin from #channel says: hi all'

Checks if user online first and says "User not online."
"""


class Plugin:
    def __init__(self):
        pass

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:][0].split()
            if info["command"] == "PRIVMSG" and msgs[0] == ".send":
                message = ""
                # Take raw suffix and pull out sender name from before !
                bang = info["prefix"].find("!")
                channel_destination = msgs[1]
                sender = info["prefix"][0:bang]
                sender_channel = info["address"]

                # Checks for general message type
                if len(msgs) >= 3 and msgs[2][0] != ".":
                    message = Plugin.send_general_message(msgs, sender, sender_channel)
                    methods["send"](channel_destination, message)
                # Checks for specific message type
                elif len(msgs) >= 6 and msgs[2] == ".u" and msgs[4] == ".m":
                    recipient = msgs[3]

                    # Sends whois to server to determine online status
                    methods["send_raw"](f"whois {recipient} \r\n")

                    # Recieves message back from server and converts to be
                    # usable.
                    data = self.irc.recv(2048)
                    raw_msg = data.decode("UTF-8")
                    msg = raw_msg.strip("\n\r")

                    if msg.endswith("No such nick/channel"):
                        methods["send"](info["address"], sender + " isn't online.")
                    else:
                        message = Plugin.send_specific_message(
                            msgs, recipient, sender, sender_channel
                        )
                    methods["send"](channel_destination, message)
                else:
                    methods["send"](
                        info["address"],
                        "Command input error. Needs to be '.send "
                        + "#channel message' or '.send #channel .u "
                        + "username .m message'.",
                    )
        except Exception as e:
            print("woops plugin error: ", e)

    def send_general_message(msgs, sender, sender_channel):
        message = ""
        for word in msgs[2:]:
            message += word + " "
        complete_message = f"{sender} from {sender_channel} says: {message.rstrip()}"
        return complete_message

    def send_specific_message(msgs, recipient, sender, sender_channel):
        message = ""
        for word in msgs[5:]:
            message += word + " "
        complete_message = "{} from {} says to {}: {}".format(
            sender, sender_channel, recipient, message.rstrip()
        )
        return complete_message



import os

import pkg_resources

_package_name = "honeybot"


def prevent_none(x):
    return x if x else ""


def configfile_to_list(settings_path, filename):
    elements = []
    with open(os.path.join(settings_path, f"{filename}.conf")) as f:
        elements = f.read().split("\n")
        elements = list(filter(lambda x: x != "", elements))
    return elements


def get_requirements():
    package = pkg_resources.working_set.by_key[_package_name]
    return [str(r) for r in package.requires()]



""" poker hand evaluator """

# pylint: disable=W0612

import itertools


def best_hand(hand):
    """from a 7-card hand, return the best 5 card hand"""

    return max(itertools.combinations(hand, 5), key=hand_rank)


def hand_rank(hand):
    """return a value indicating the ranking of a hand"""

    ranks = card_ranks(hand)
    if straight(ranks) and flush(hand):
        return 8, max(ranks)

    elif kind(4, ranks):
        # four of a kind
        return 7, kind(4, ranks), kind(1, ranks)

    elif kind(3, ranks) and kind(2, ranks):
        # full house
        return 6, kind(3, ranks), kind(2, ranks)

    elif flush(hand):
        # all cards of same suit
        return 5, ranks

    elif straight(ranks):
        # cards in sequence
        return 4, max(ranks)

    elif kind(3, ranks):
        # 3 cards of same rank
        return 3, kind(3, ranks), ranks

    elif two_pair(ranks):
        # 2 pairs of same rank
        return 2, two_pair(ranks), ranks

    elif kind(2, ranks):
        # 1 pair of same rank
        return 1, kind(2, ranks), ranks

    else:
        # Nothing (High Card)
        return 0, ranks


def card_ranks(hand):
    """return a list of the ranks, sorted with higher first"""

    ranks = ["--23456789TJQKA".index(r) for r, s in hand]
    ranks.sort(reverse=True)
    # to handle the (A-5) straight case
    return [5, 4, 3, 2, 1] if (ranks == [14, 5, 4, 3, 2]) else ranks


def flush(hand):
    """return True if all the cards have the same suit"""

    suits = [s for r, s in hand]
    return len(set(suits)) == 1


def straight(ranks):
    """return True if the ordered ranks form a 5-card straight"""

    return (max(ranks) - min(ranks) == 4) and len(set(ranks)) == 5


def kind(n, ranks):
    """
    return the first rank that this hand has exactly n-of-a-kind of.
    Return None if there is no n-of-a-kind in the hand
    """

    for r in ranks:

        if ranks.count(r) == n:
            return r

    return None


def two_pair(ranks):
    """if there are two pair here, return the two ranks of the two pairs, else None"""

    pair = kind(2, ranks)
    lowpair = kind(2, list(reversed(ranks)))
    if pair and lowpair != pair:
        return pair, lowpair

    else:
        return None


def test_best_hand(playerhand):
    # S = Spade
    # D = Diamond
    # C = Club
    # H = Heart
    # assert (sorted(best_hand('6C 7C 8C 9C TC 5C JS'.split())) ==
    # ['6C', '7C', '8C', '9C', 'TC'])
    # assert (sorted(best_hand('TD TC TH 7C 7D 8C 8S'.split())) ==
    # ['8C', '8S', 'TC', 'TD', 'TH'])
    # assert (sorted(best_hand('JD TC TH 7C 7D 7S 7H'.split())) ==
    # ['7C', '7D', '7H', '7S', 'JD'])
    # return 'test_best_hand passes'
    # return sorted(best_hand('2D 2C 2H 7C 7D KC KS'.split()))
    return sorted(best_hand(playerhand.split()))



""" hand class """

# pylint: disable=E1601

# parts not necessary for blackjack but required for poker commented out

# import deuces "deuces==0.2",
# import best5
# import board
# import card


class Hand:
    """hand class"""

    def __init__(self, hand):
        """hand initialization"""

        self.__hand = hand
        self.__card1 = hand[0]
        self.__card2 = hand[1]

    def show_hand(self):
        """show hand"""

        return self.__hand

    def show_hand_obj(self):
        """show hand object"""

        return self.__hand

    """
    def best_five(self, b):
        ''' best 5 out of 7 '''

        try:
            print(b.flop1())
            print(b.flop2())
            print(b.flop3())
            print(b.turn())
            print(b.river())
            print(" ".join([c.show_card() for c in self.show_hand()]))
            hand_and_board = self.show_hand()[0].show_card() + ' ' +\
            self.show_hand()[1].show_card() + ' ' + b.flop1() + ' ' +\
            b.flop2() + ' ' + b.flop3() + ' ' + b.turn() + ' ' + b.river()

            return(" ".join([c for c in best5.test_best_hand(hand_and_board)]))
        except Exception:
            return "error with non board object"

    def hand_strength(self, board):
        ''' hand strength '''

        evaluator = deuces.Evaluator()
        b5 = self.best_five(board)
        h1 = b5[:2].replace('S', 's').replace('H', 'h').replace('D', 'd')\
            .replace('C', 'c')
        h2 = b5[3:5].replace('S', 's').replace('H', 'h').replace('D', 'd')\
            .replace('C', 'c')
        b1 = b5[6:8].replace('S', 's').replace('H', 'h').replace('D', 'd')\
            .replace('C', 'c')
        b2 = b5[9:11].replace('S', 's').replace('H', 'h').replace('D', 'd')\
            .replace('C', 'c')
        b3 = b5[12:14].replace('S', 's').replace('H', 'h').replace('D', 'd')\
            .replace('C', 'c')
        hl = [deuces.Card.new(h1), deuces.Card.new(h2)]
        bl = [deuces.Card.new(b1), deuces.Card.new(b2), deuces.Card.new(b3)]
        strength = evaluator.evaluate(bl, hl)

        return strength
    """

    def hand_total(self):
        """hand total for blackjack"""

        total = 0
        for card in self.__hand:
            total += card.blackjack_value()
        return total



NAME = "horoscope.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
Returns your daily horoscope based on your star sign
you can also enter your month and date of birth to automatically find your starsign
enter month and date as number
"""

COMMANDS = """
>>> .horoscope <<starsign>>
returns horoscope for starsign

.horoscope <<month>> <<day>>
returns horoscope for starsign of day entered
"""

WEBSITE = ""



"""
[url_shorten.py]
URL Shortener Plugin

[Author]
Rakesh Seal

[About]
Shorten an url with cleanuri and returns the smaller url.
[Website]


[Commands]
>>> .url_shorten <url>
Shorten an url with cleanuri and returns the smaller url.
"""

import requests


class Plugin:
    def __init__(self):
        self.url = "https://cleanuri.com/api/v1/shorten"

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:][0].split()
            if info["command"] == "PRIVMSG" and msgs[0] == ".url_shorten":
                query = msgs[
                    1
                ]  # not entertaining multiple url. also assuming url is encoded i.e. no space will be there inside url.
                short_url = (
                    requests.post(self.url, json={"url": query}).json().get("result_url", "")
                )
                methods["send"](info["address"], short_url)
        except Exception as e:
            print("unexpected error occured!", e)



"""
[bitcoin.py]
Bitcoin Price Checking Plugin

[Author]
Gabriele Ron

[Website]
https://Macr0Nerd.github.io

[About]
Checks the current price for Bitcoin through the Legacy Coin Market Cap API
TODO: Update API to new Coin Market Cap API

[Commands]
>>> .btc
returns current value of bitcoin
"""

import requests


class Plugin:
    def __init__(self):
        self.api_url = "https://api.coinmarketcap.com/v1/ticker/bitcoin/"
        pass

    def run(self, incoming, methods, info, bot_info):
        try:
            # msgs = info['args'][1:][0].split()

            if info["command"] == "PRIVMSG" and info["args"][1] == ".btc":
                response = requests.get("https://api.coinmarketcap.com/v1/ticker/bitcoin/")
                response_json = response.json()
                methods["send"](info["address"], "$" + response_json[0]["price_usd"])

        except Exception as e:
            print("woops plugin", __file__, e)



import configparser

memory_reader = configparser.ConfigParser()


def add_value(memfile, section, key, value):
    memory_reader.read(f"memory/{memfile}.txt")
    memory_reader[section][key] = value
    with open(f"memory/{memfile}.txt", "w") as file:
        memory_reader.write(file)


def remove_value(memfile, section, key):
    memory_reader.read(f"memory/{memfile}.txt")
    memory_reader.remove_option(section, key)
    with open(f"memory/{memfile}.txt", "w") as file:
        memory_reader.write(file)


def fetch_value(memfile, section, key):
    memory_reader.read(f"memory/{memfile}.txt")
    return memory_reader[section][key]



"""
[blackjack.py]
Blackjack Plugin
[Author]
Angelo Giacco
[About]
Play blackjack
[Commands]
>>>.blackjack create
creates blackjack game

>>>.blackjack join
join blackjack game

>>>.blackjack start
start a round

>>>.blackjack hit
get another card

>>>.blackjack stand
move on to next player
"""


import poker_assets.card
import poker_assets.deck
import poker_assets.hand
import poker_assets.player


class Plugin:
    bj_created = False
    round_started = False
    turn = 0
    player_lst = []
    starting_chips = 100
    winner = None
    end = False

    def __init__(self):
        pass

    """
    USEFUL FUNCTIONS
    """

    def next_turn(methods, info):
        """increment turn and find winner if hitting and standing over"""

        try:
            Plugin.turn += 1
            if Plugin.turn == len(Plugin.player_lst):
                # all players have find winner
                total_lst = [player.show_player_hand().hand_total() for player in Plugin.player_lst]
                index, value = max(list(enumerate(total_lst)), key=lambda x: x[1])
                if total_lst.count(value) == 1:
                    Plugin.winner = Plugin.player_lst[index].get_name()
                    methods["send"](info["address"], "The winner is " + Plugin.winner + "!")
                else:
                    methods["send"](info["address"], "This round has ended in a draw!")
                Plugin.bj_created = False
        except Exception as e:
            print("woops, blackjack turn change error ", e)

    def initPlayer(methods, info):
        """add a player to the round"""

        if Plugin.bj_created:
            if not Plugin.round_started:
                name = info["prefix"].split("!")[0]
                if len(Plugin.player_lst) <= 5:  # limit game to 6 players
                    if not (name in [player.get_name() for player in Plugin.player_lst]):
                        Plugin.player_lst.append(
                            poker_assets.player.Player(
                                len(Plugin.player_lst), Plugin.starting_chips, name
                            )
                        )
                        methods["send"](info["address"], name + " joined the game!")
                    else:
                        methods["send"](info["address"], "You are already in this round!")
                else:
                    methods["send"](info["address"], "This round is full already")
            else:
                methods["send"](
                    info["address"],
                    "The round has started, wait for a new one to join!",
                )
        else:
            methods["send"](info["address"], "A game has not yet been created!")

    def checkHand(methods, info, player):
        """check the value of a player's hand"""

        name = player.get_name()
        total = player.show_player_hand().hand_total()
        cards = " ".join(
            [poker_assets.card.show_card() for card in player.show_player_hand().show_hand_obj()]
        )
        if total > 21:
            methods["send"](
                info["address"],
                name
                + "'s hand "
                + cards
                + " has a value of "
                + str(total)
                + " so you have been kicked out",
            )
            for p in Plugin.player_lst:
                if p.get_name() == name:
                    Plugin.player_lst.remove(p)
            if len(Plugin.player_lst) == 1:
                Plugin.winner = Plugin.player_lst[0].get_name()
                methods["send"](info["address"], "The winner is " + Plugin.winner + "!")
                Plugin.bj_created = False
        elif total == 21:
            methods["send"](
                info["address"],
                name + "'s hand " + cards + " has a value of 21 so you have won!",
            )
            Plugin.winner = name
            Plugin.bj_created = False
        else:
            methods["send"](
                info["address"],
                name + "'s hand " + cards + " has a value of " + str(total) + ".",
            )

    """
    COMMAND FUNCTIONS
    """

    def initGame(methods, info):
        """create a new round"""

        if not Plugin.bj_created:
            Plugin.turn = 0
            Plugin.winner = None
            Plugin.player_lst = []
            name = info["prefix"].split("!")[0]
            Plugin.bj_created = True
            Plugin.round_started = False
            Plugin.initPlayer(methods, info)
            Plugin.DECK = poker_assets.deck.Deck()
            methods["send"](
                info["address"],
                name + " has started a game of blackjack! Use .blackjack join to join in!",
            )
        else:
            methods["send"](info["address"], "A game already exists!")

    def start(methods, info):
        """start the game"""

        Plugin.round_started = True
        Plugin.bj_created = True
        for player in Plugin.player_lst:
            player.add_hand(poker_assets.hand.Hand(Plugin.DECK.make_hand()))
            total = player.show_player_hand().hand_total()
            cards = " ".join(
                [
                    poker_assets.card.show_card()
                    for card in player.show_player_hand().show_hand_obj()
                ]
            )
            Plugin.checkHand(methods, info, player)

    def hit(methods, info):
        """give player a new card"""

        name = info["prefix"].split("!")[0]
        if Plugin.winner is None:
            if Plugin.player_lst[Plugin.turn].get_name() == name:
                Plugin.player_lst[Plugin.turn].add_card_to_hand(Plugin.DECK.draw_random_card())
                Plugin.checkHand(methods, info, Plugin.player_lst[Plugin.turn])
            else:
                methods["send"](info["address"], "It is not your turn!")
        else:
            methods["send"](
                info["address"],
                "The round is already over and has been won by " + Plugin.winner,
            )

    def stand(methods, info):
        """player chooses not to get a new car"""
        name = info["prefix"].split("!")[0]
        if Plugin.winner is None:
            if Plugin.turn < len(Plugin.player_lst):
                if Plugin.player_lst[Plugin.turn].get_name() == name:
                    methods["send"](
                        info["address"],
                        info["prefix"].split("!")[0] + " has chosen not to pick another card!",
                    )
                    Plugin.next_turn(methods, info)
                else:
                    methods["send"](info["address"], "It is not your turn!")
            else:
                methods["send"](info["adress"], "something went wrong, please try restarting")
                Plugin.bj_created = False
        else:
            methods["send"](info["address"], Plugin.winner + " has already won the game!")

    """
    RUNNING PLUGIN
    """

    def run(self, methods, info):
        try:
            msgs = info["args"][1:][0].split()
            if (
                info["command"] == "PRIVMSG"
                and (msgs[0] == ".bj" or msgs[0] == ".21" or msgs[0] == ".blackjack")
                and len(msgs) == 2
            ):
                if msgs[1] == "create":
                    Plugin.initGame(methods, info)
                elif msgs[1] == "join":
                    Plugin.initPlayer(methods, info)
                elif msgs[1] == "start":
                    Plugin.start(methods, info)
                elif msgs[1] == "hit":
                    Plugin.hit(methods, info)
                elif msgs[1] == "stand":
                    Plugin.stand(methods, info)
                else:
                    methods["send"](info["address"], "invalid blackjack command")
        except Exception as e:
            print("woops blackjack plugin error: ", e)



"""
[dictionary.py]
Dictionary Plugin

[Author]
Milad H,

[About]
Searches the python documentatioin(pydocs) for the related keyword(s)
and returns some of the relevant links


[Commands]
>>> .pydocs <keyword>
returns links in python documentation related to the keyword
"""
from PyDictionary import PyDictionary


class Plugin:
    def __init__(self):
        pass

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:][0].split()

            if info["command"] == "PRIVMSG" and msgs[0] == ".dictionary":
                dict = PyDictionary()
                word = str(msgs[1])
                defin = dict.meaning(word)["Noun"]
                for definition in defin:
                    methods["send"](info["address"], definition)
        except Exception as e:
            print("woops plug", e)



NAME = "monero.py"
ORIGINAL_AUTHORS = ["A. Eigenbrot"]

ABOUT = """
Checks the current price for Monero via the cryptocompare.com API
"""

COMMANDS = """
>>> .xmr [currency]
returns current value of Monero in the currency specified (default is USD).
Currency must be a 3-letter capital string.
Examples: USD, EUR, BTC, GBP
"""

WEBSITE = ""



NAME = "wikipedia.py"
ORIGINAL_AUTHORS = ["Gabriele Ron"]

ABOUT = """
sends a wikipedia article on request based off of a search or random query
requires wikipedia library. Can use pip -> "pip install wikipedia"
"""

COMMANDS = """
>>> .wiki <command> <topic>
returns a wikipedia article
"""

WEBSITE = "https://Macr0Nerd.github.io"



"""
[maths.py]
Miscellaneous Maths Operations Plugin

[Author]
Abdur-Rahmaan Janhangeer, pythonmembers.club

[About]
some maths related commands

[Commands]
>>> .sin <number>
returns sine of number

>>> .cos <number>
returns cosine of number

>>> .tan <number>
returns tangent of number

>>> .rand <number1> <number2>
returns number between number1 and number2
"""
import math
import random


class Plugin:
    def __init__(self):
        pass

    def run(self, incoming, methods, info, bot_info):
        try:
            # if '!~' in info['prefix']:
            # print(info)
            msgs = info["args"][1:][0].split()
            if info["command"] == "PRIVMSG":
                if len(msgs) > 1:
                    if msgs[0] == ".sin":
                        try:
                            sine = math.sin(float(msgs[1]))
                            methods["send"](info["address"], f"{sine}")
                        except ValueError:
                            methods["send"](info["address"], ".sin must have numbers")
                    elif msgs[0] == ".cos":
                        try:
                            cosine = math.cos(float(msgs[1]))
                            methods["send"](info["address"], f"{cosine}")
                        except ValueError:
                            methods["send"](info["address"], ".cos must have numbers")
                    elif msgs[0] == ".tan":
                        try:
                            tangent = math.tan(float(msgs[1]))
                            methods["send"](info["address"], f"{tangent}")
                        except ValueError:
                            methods["send"](info["address"], ".tan must have numbers")
                    elif msgs[0] == ".rand":
                        try:
                            if int(msgs[1]) >= int(msgs[2]):
                                methods["send"](
                                    info["address"],
                                    ".rand requires two integers that are not "
                                    "equal and the first must be biggest",
                                )
                            else:
                                rand = random.randint(int(msgs[1]), int(msgs[2]))
                                methods["send"](info["address"], f"{rand}")
                        except ValueError:
                            methods["send"](info["address"], ".rand must have numbers")
        except Exception as e:
            print("\n*error*\nwoops plugin", __file__, e, "\n")
